@@ -2,8 +2,8 @@
  * InspIRCd -- Internet Relay Chat Daemon
  *
  *   Copyright (C) 2020 Matt Schatz <genius3000@g3k.solutions>
+ *   Copyright (C) 2013, 2017, 2020-2021 Sadie Powell <sadie@witchery.services>
  *   Copyright (C) 2013, 2015 Attila Molnar <attilamolnar@hush.com>
- *   Copyright (C) 2012-2013, 2017 Sadie Powell <sadie@witchery.services>
  *   Copyright (C) 2012 Robby <robby@chatbelgie.be>
  *   Copyright (C) 2012 ChrisTX <xpipe@hotmail.de>
  *   Copyright (C) 2011-2012 Adam <Adam@anope.org>
@@ -28,10 +28,8 @@
 
 #pragma once
 
-#include <map>
-#include <deque>
+#include "compat.h"
 #include <string>
-#include <list>
 
 /** Dummy class to help enforce culls being parent-called up to classbase */
 class CullResult
@@ -259,6 +257,9 @@ class CoreExport ServiceProvider : public classbase
 	ServiceProvider(Module* Creator, const std::string& Name, ServiceType Type);
 	virtual ~ServiceProvider();
 
+	/** Retrieves a string that represents the type of this service. */
+	const char* GetTypeString() const;
+
 	/** Register this service in the appropriate registrar
 	 */
 	virtual void RegisterService();
