@@ -2,7 +2,7 @@
  * InspIRCd -- Internet Relay Chat Daemon
  *
  *   Copyright (C) 2014 Attila Molnar <attilamolnar@hush.com>
- *   Copyright (C) 2013, 2016 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2013, 2016, 2021 Sadie Powell <sadie@witchery.services>
  *   Copyright (C) 2012 Robby <robby@chatbelgie.be>
  *   Copyright (C) 2009-2010 Daniel De Graaf <danieldg@inspircd.org>
  *
@@ -30,13 +30,7 @@ struct ParseStack
 	ConfigFileCache& FilesOutput;
 	std::stringstream& errstr;
 
-	ParseStack(ServerConfig* conf)
-		: output(conf->config_data), FilesOutput(conf->Files), errstr(conf->errstr)
-	{
-		vars["amp"] = "&";
-		vars["quot"] = "\"";
-		vars["newline"] = vars["nl"] = "\n";
-	}
+	ParseStack(ServerConfig* conf);
 	bool ParseFile(const std::string& name, int flags, const std::string& mandatory_tag = std::string(), bool isexec = false);
 	void DoInclude(ConfigTag* includeTag, int flags);
 	void DoReadFile(const std::string& key, const std::string& file, int flags, bool exec);
