@@ -2,7 +2,7 @@
  * InspIRCd -- Internet Relay Chat Daemon
  *
  *   Copyright (C) 2013-2016 Attila Molnar <attilamolnar@hush.com>
- *   Copyright (C) 2012-2013, 2017-2020 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2012-2013, 2017-2021 Sadie Powell <sadie@witchery.services>
  *   Copyright (C) 2012 Robby <robby@chatbelgie.be>
  *   Copyright (C) 2009 Daniel De Graaf <danieldg@inspircd.org>
  *   Copyright (C) 2008 Thomas Stagner <aquanight@inspircd.org>
@@ -99,7 +99,7 @@ class ParamModeBase;
 class CoreExport ModeHandler : public ServiceProvider
 {
  public:
-  	typedef size_t Id;
+	typedef size_t Id;
 
 	enum Class
 	{
@@ -274,6 +274,7 @@ class CoreExport ModeHandler : public ServiceProvider
 	 * @return MODEACTION_ALLOW to allow the mode, or MODEACTION_DENY to prevent the mode, also see the description of 'parameter'.
 	 */
 	virtual ModeAction OnModeChange(User* source, User* dest, Channel* channel, std::string &parameter, bool adding); /* Can change the mode parameter as its a ref */
+
 	/**
 	 * If your mode is a listmode, then this method will be called for displaying an item list, e.g. on MODE \#channel +modechar
 	 * without any parameter or other modes in the command.
@@ -290,6 +291,15 @@ class CoreExport ModeHandler : public ServiceProvider
 	 */
 	virtual void OnParameterMissing(User* user, User* dest, Channel* channel);
 
+	/** Called when a user attempts to set a mode and the parameter is invalid.
+	 * @param user The user issuing the mode change
+	 * @param targetchannel Either the channel target or NULL if changing a user mode.
+	 * @param targetuser Either the user target or NULL if changing a channel mode.
+	 * @param parameter The invalid parameter.
+	 */
+	virtual void OnParameterInvalid(User* user, Channel* targetchannel, User* targetuser, const std::string& parameter);
+
+
 	/**
 	 * If your mode is a listmode, this method will be called to display an empty list (just the end of list numeric)
 	 * @param user The user issuing the command
@@ -529,7 +539,7 @@ class CoreExport ModeWatcher : public classbase
 	 * @param dest The target user for the mode, if you are watching a user mode
 	 * @param channel The target channel for the mode, if you are watching a channel mode
 	 * @param parameter The parameter of the mode, if the mode is supposed to have a parameter.
-	 * If you alter the parameter you are given, the mode handler will see your atered version
+	 * If you alter the parameter you are given, the mode handler will see your altered version
 	 * when it handles the mode.
 	 * @param adding True if the mode is being added and false if it is being removed
 	 * @return True to allow the mode change to go ahead, false to abort it. If you abort the
@@ -569,7 +579,7 @@ class CoreExport ModeParser : public fakederef<ModeParser>
  private:
 	/** Type of the container that maps mode names to ModeWatchers
 	 */
- 	typedef insp::flat_multimap<std::string, ModeWatcher*> ModeWatcherMap;
+	typedef insp::flat_multimap<std::string, ModeWatcher*> ModeWatcherMap;
 
 	/** Last item in the ModeType enum
 	 */
@@ -611,10 +621,14 @@ class CoreExport ModeParser : public fakederef<ModeParser>
 	 */
 	Modes::ChangeList LastChangeList;
 
-	/**
-	 * Attempts to apply a mode change to a user or channel
+	/** Attempts to apply a mode change to a user or channel
+	 * @param user The user who triggered the mode change.
+	 * @param usertarget If non-NULL then the user to change the modes of.
+	 * @param chantarget If non-NULL then the channel to change the modes of.
+	 * @param mcitem The actual mode change to attempt.
+	 * @param skipacl Whether to skip access checks for the mode change.
 	 */
-	ModeAction TryMode(User* user, User* targu, Channel* targc, Modes::Change& mcitem, bool SkipACL);
+	ModeAction TryMode(User* user, User* usertarget, Channel* chantarget, Modes::Change& mcitem, bool skipacl);
 
 	/** Allocates an unused id for the given mode type, throws a ModuleException if out of ids.
 	 * @param mt The type of the mode to allocate the id for
@@ -671,7 +685,7 @@ class CoreExport ModeParser : public fakederef<ModeParser>
 	 *
 	 * host.name -> *!*\@host.name
 	 *
-	 * ident@host.name -> *!ident\@host.name
+	 * ident\@host.name -> *!ident\@host.name
 	 *
 	 * This method can be used on both IPV4 and IPV6 user masks.
 	 */
