@@ -5,15 +5,16 @@
  *   Copyright (C) 2019 iwalkalone <iwalkalone69@gmail.com>
  *   Copyright (C) 2013 Adam <Adam@anope.org>
  *   Copyright (C) 2012-2016, 2018 Attila Molnar <attilamolnar@hush.com>
- *   Copyright (C) 2012-2013, 2017-2020 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2012-2013, 2017-2021 Sadie Powell <sadie@witchery.services>
  *   Copyright (C) 2012 Robby <robby@chatbelgie.be>
  *   Copyright (C) 2009-2010 Daniel De Graaf <danieldg@inspircd.org>
  *   Copyright (C) 2009 Uli Schlachter <psychon@inspircd.org>
  *   Copyright (C) 2008 Thomas Stagner <aquanight@inspircd.org>
  *   Copyright (C) 2007-2009 Robin Burchell <robin+git@viroteck.net>
- *   Copyright (C) 2007-2008, 2010 Craig Edwards <brain@inspircd.org>
  *   Copyright (C) 2007 Oliver Lupton <om@inspircd.org>
- *   Copyright (C) 2007 Dennis Friis <peavey@inspircd.org>
+ *   Copyright (C) 2006-2007 Dennis Friis <peavey@inspircd.org>
+ *   Copyright (C) 2006 John Brooks <special@inspircd.org>
+ *   Copyright (C) 2003-2008, 2010 Craig Edwards <brain@inspircd.org>
  *
  * This file is part of InspIRCd.  InspIRCd is free software: you can
  * redistribute it and/or modify it under the terms of the GNU General Public
@@ -36,7 +37,6 @@
 #include "base.h"
 #include "ctables.h"
 #include "inspsocket.h"
-#include "timer.h"
 #include "mode.h"
 
 /** Used to specify the behaviour of a module. */
@@ -239,8 +239,8 @@ enum Implementation
 	I_OnBackgroundTimer,
 	I_OnBuildNeighborList,
 	I_OnChangeHost,
-	I_OnChangeRealHost,
 	I_OnChangeIdent,
+	I_OnChangeRealHost,
 	I_OnChangeRealName,
 	I_OnChannelDelete,
 	I_OnChannelPreDelete,
@@ -264,6 +264,7 @@ enum Implementation
 	I_OnNumeric,
 	I_OnOper,
 	I_OnPassCompare,
+	I_OnPostChangeRealHost,
 	I_OnPostCommand,
 	I_OnPostConnect,
 	I_OnPostDeoper,
@@ -492,7 +493,7 @@ class CoreExport Module : public classbase, public usecountbase
 	 * @param user The user joining the channel
 	 * @param chan If the  channel is a new channel, this will be NULL, otherwise it will be a pointer to the channel being joined
 	 * @param cname The channel name being joined. For new channels this is valid where chan is not.
-	 * @param privs A string containing the users privilages when joining the channel. For new channels this will contain "o".
+	 * @param privs A string containing the users privileges when joining the channel. For new channels this will contain "o".
 	 * You may alter this string to alter the user's modes on the channel.
 	 * @param keygiven The key given to join the channel, or an empty string if none was provided
 	 * @return 1 To prevent the join, 0 to allow it.
@@ -591,7 +592,7 @@ class CoreExport Module : public classbase, public usecountbase
 
 	/** Called before local nickname changes. This can be used to implement Q-lines etc.
 	 * If your method returns nonzero, the nickchange is silently forbidden, and it is down to your
-	 * module to generate some meaninful output.
+	 * module to generate some meaningful output.
 	 * @param user The username changing their nick
 	 * @param newnick Their new nickname
 	 * @return 1 to deny the change, 0 to allow
@@ -648,18 +649,24 @@ class CoreExport Module : public classbase, public usecountbase
 
 	/** Called whenever a user's hostname is changed.
 	 * This event triggers after the host has been set.
-	 * @param user The user whos host is being changed
+	 * @param user The user whose host is being changed
 	 * @param newhost The new hostname being set
 	 */
 	virtual void OnChangeHost(User* user, const std::string &newhost);
 
 	/** Called whenever a user's real hostname is changed.
-	 * This event triggers after the host has been set.
-	 * @param user The user whos host is being changed
+	 * This event triggers before the host has been set.
+	 * @param user The user whose host is being changed
 	 * @param newhost The new hostname being set
 	 */
 	virtual void OnChangeRealHost(User* user, const std::string& newhost);
 
+	/** Called whenever a user's real hostname is changed.
+	 * This event triggers after the host has been set.
+	 * @param user The user whos host was changed.
+	 */
+	virtual void OnPostChangeRealHost(User* user);
+
 	/** Called whenever a user's real name is changed.
 	 * This event triggers after the name has been set.
 	 * @param user The user who's real name is being changed
@@ -706,7 +713,7 @@ class CoreExport Module : public classbase, public usecountbase
 
 	/** Called after any nickchange, local or remote. This can be used to track users after nickchanges
 	 * have been applied. Please note that although you can see remote nickchanges through this function, you should
-	 * NOT make any changes to the User if the user is a remote user as this may cause a desnyc.
+	 * NOT make any changes to the User if the user is a remote user as this may cause a desync.
 	 * check user->server before taking any action (including returning nonzero from the method).
 	 * Because this method is called after the nickchange is taken place, no return values are possible
 	 * to indicate forbidding of the nick change. Use OnUserPreNick for this.
@@ -823,14 +830,14 @@ class CoreExport Module : public classbase, public usecountbase
 
 	/** Called after a user object is initialised and added to the user list.
 	 * When this is called the user has not had their I/O hooks checked or had their initial
-	 * connect class assigned and may not yet have a serialiser. You probably want to use
+	 * connect class assigned and may not yet have a serializer. You probably want to use
 	 * the OnUserPostInit or OnUserSetIP hooks instead of this one.
 	 * @param user The connecting user.
 	 */
 	virtual void OnUserInit(LocalUser* user);
 
 	/** Called after a user object has had their I/O hooks checked, their initial connection
-	 * class assigned, and had a serialiser set.
+	 * class assigned, and had a serializer set.
 	 * @param user The connecting user.
 	 */
 	virtual void OnUserPostInit(LocalUser* user);
@@ -930,7 +937,7 @@ class CoreExport Module : public classbase, public usecountbase
 
 	/** Called whenever a change of a local users displayed host is attempted.
 	 * Return 1 to deny the host change, or 0 to allow it.
-	 * @param user The user whos host will be changed
+	 * @param user The user whose host will be changed
 	 * @param newhost The new hostname
 	 * @return 1 to deny the host change, 0 to allow
 	 */
@@ -938,7 +945,7 @@ class CoreExport Module : public classbase, public usecountbase
 
 	/** Called whenever a change of a local users real name is attempted.
 	 * return MOD_RES_DENY to deny the name change, or MOD_RES_ALLOW to allow it.
-	 * @param user The user whos real name will be changed
+	 * @param user The user whose real name will be changed
 	 * @param newhost The new real name.
 	 * @return MOD_RES_DENY to deny the real name change, MOD_RES_ALLOW to allow
 	 */
@@ -1050,6 +1057,7 @@ class CoreExport Module : public classbase, public usecountbase
 class CoreExport ModuleManager : public fakederef<ModuleManager>
 {
  public:
+	typedef std::multimap<std::string, ServiceProvider*, irc::insensitive_swo> DataProviderMap;
 	typedef std::vector<ServiceProvider*> ServiceList;
 
  private:
@@ -1092,7 +1100,7 @@ class CoreExport ModuleManager : public fakederef<ModuleManager>
 	Module::List EventHandlers[I_END];
 
 	/** List of data services keyed by name */
-	std::multimap<std::string, ServiceProvider*, irc::insensitive_swo> DataProviders;
+	DataProviderMap DataProviders;
 
 	/** A list of ServiceProviders waiting to be registered.
 	 * Non-NULL when constructing a Module, NULL otherwise.
