@@ -1,7 +1,7 @@
 /*
  * InspIRCd -- Internet Relay Chat Daemon
  *
- *   Copyright (C) 2018-2019 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2018-2021 Sadie Powell <sadie@witchery.services>
  *   Copyright (C) 2015, 2018 Attila Molnar <attilamolnar@hush.com>
  *
  * This file is part of InspIRCd.  InspIRCd is free software: you can
@@ -31,8 +31,10 @@ namespace IRCv3
 
 class IRCv3::WriteNeighborsWithCap : public User::ForEachNeighborHandler
 {
+ private:
 	const Cap::Capability& cap;
 	ClientProtocol::Event& protoev;
+	already_sent_t sentid;
 
 	void Execute(LocalUser* user) CXX11_OVERRIDE
 	{
@@ -45,8 +47,10 @@ class IRCv3::WriteNeighborsWithCap : public User::ForEachNeighborHandler
 		: cap(capability)
 		, protoev(ev)
 	{
-		user->ForEachNeighbor(*this, include_self);
+		sentid = user->ForEachNeighbor(*this, include_self);
 	}
+
+	already_sent_t GetAlreadySentId() const { return sentid; }
 };
 
 /** Base class for simple message tags.
@@ -100,4 +104,7 @@ class IRCv3::CapTag : public ClientProtocol::MessageTagProvider
 		, tagname(Tagname)
 	{
 	}
+
+	/** Retrieves the underlying capability. */
+	const Cap::Capability& GetCap() const { return cap; }
 };
