@@ -4,7 +4,7 @@
  *   Copyright (C) 2020 Matt Schatz <genius3000@g3k.solutions>
  *   Copyright (C) 2019 B00mX0r <b00mx0r@aureus.pw>
  *   Copyright (C) 2018 Dylan Frank <b00mx0r@aureus.pw>
- *   Copyright (C) 2013, 2017-2019 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2013, 2017-2019, 2021 Sadie Powell <sadie@witchery.services>
  *   Copyright (C) 2013, 2015-2016 Attila Molnar <attilamolnar@hush.com>
  *   Copyright (C) 2012 Robby <robby@chatbelgie.be>
  *   Copyright (C) 2012 ChrisTX <xpipe@hotmail.de>
@@ -110,7 +110,7 @@ class ssl_cert : public refcountbase
 		return unknownsigner;
 	}
 
-	/** Get revokation status.
+	/** Get revocation status.
 	 * @return True if the certificate is revoked.
 	 * Note that this only works properly for GnuTLS
 	 * right now.
@@ -151,13 +151,39 @@ class ssl_cert : public refcountbase
 	}
 };
 
+/** I/O hook provider for SSL modules. */
+class SSLIOHookProvider : public IOHookProvider
+{
+public:
+	SSLIOHookProvider(Module* mod, const std::string& Name)
+		: IOHookProvider(mod, "ssl/" + Name, IOH_SSL)
+	{
+	}
+};
+
 class SSLIOHook : public IOHook
 {
  protected:
+	/** An enumeration of possible TLS (SSL) socket states. */
+	enum Status
+	{
+		/** The SSL socket has just been opened or has been closed. */
+		STATUS_NONE,
+
+		/** The SSL socket is currently handshaking. */
+		STATUS_HANDSHAKING,
+
+		/** The SSL handshake has completed and data can be sent. */
+		STATUS_OPEN
+	};
+
 	/** Peer TLS (SSL) certificate, set by the TLS (SSL) module
 	 */
 	reference<ssl_cert> certificate;
 
+	/** The status of the TLS (SSL) connection. */
+	Status status;
+
 	/** Reduce elements in a send queue by appending later elements to the first element until there are no more
 	 * elements to append or a desired length is reached
 	 * @param sendq SendQ to work on
@@ -232,6 +258,9 @@ class SSLIOHook : public IOHook
 	 * returns True if the server name was retrieved; otherwise, false.
 	 */
 	virtual bool GetServerName(std::string& out) const = 0;
+
+	/** @copydoc IOHook::IsHookReady */
+	bool IsHookReady() const CXX11_OVERRIDE { return status == STATUS_OPEN; }
 };
 
 /** Helper functions for obtaining TLS (SSL) client certificates and key fingerprints
@@ -240,7 +269,7 @@ class SSLIOHook : public IOHook
 class SSLClientCert
 {
  public:
- 	/**
+	/**
 	 * Get the client certificate from a socket
 	 * @param sock The socket to get the certificate from, the socket does not have to use TLS (SSL)
 	 * @return The TLS (SSL) client certificate information, NULL if the peer is not using TLS (SSL)
@@ -273,7 +302,7 @@ class SSLClientCert
 class UserCertificateAPIBase : public DataProvider
 {
  public:
- 	UserCertificateAPIBase(Module* parent)
+	UserCertificateAPIBase(Module* parent)
 		: DataProvider(parent, "m_sslinfo_api")
 	{
 	}
