@@ -86,7 +86,7 @@ class Numeric::GenericBuilder
 	GenericBuilder(Sink s, unsigned int num, bool addparam = true, size_t additionalsize = 0)
 		: sink(s)
 		, numeric(num)
-		, max(ServerInstance->Config->Limits.MaxLine - ServerInstance->Config->ServerName.size() - additionalsize - 10)
+		, max(ServerInstance->Config->Limits.MaxLine - ServerInstance->Config->GetServerName().size() - additionalsize - 10)
 	{
 		if (addparam)
 			numeric.push(std::string());
@@ -156,7 +156,7 @@ class Numeric::GenericParamBuilder
 		: sink(s)
 		, numeric(num)
 		, currlen(0)
-		, max(ServerInstance->Config->Limits.MaxLine - ServerInstance->Config->ServerName.size() - additionalsize - 10)
+		, max(ServerInstance->Config->Limits.MaxLine - ServerInstance->Config->GetServerName().size() - additionalsize - 10)
 	{
 	}
 
