@@ -5,12 +5,11 @@
  *   Copyright (C) 2013-2014 Adam <Adam@anope.org>
  *   Copyright (C) 2012-2013, 2017-2020 Sadie Powell <sadie@witchery.services>
  *   Copyright (C) 2012 Robby <robby@chatbelgie.be>
+ *   Copyright (C) 2009-2010 Daniel De Graaf <danieldg@inspircd.org>
  *   Copyright (C) 2009 Uli Schlachter <psychon@inspircd.org>
- *   Copyright (C) 2009 Daniel De Graaf <danieldg@inspircd.org>
  *   Copyright (C) 2007-2008, 2017 Robin Burchell <robin+git@viroteck.net>
- *   Copyright (C) 2007-2008, 2010 Craig Edwards <brain@inspircd.org>
- *   Copyright (C) 2007 burlex <burlex@e03df62e-2008-0410-955e-edbf42e46eb7>
  *   Copyright (C) 2007 Dennis Friis <peavey@inspircd.org>
+ *   Copyright (C) 2005-2008 Craig Edwards <brain@inspircd.org>
  *
  * This file is part of InspIRCd.  InspIRCd is free software: you can
  * redistribute it and/or modify it under the terms of the GNU General Public
@@ -28,10 +27,7 @@
 
 #pragma once
 
-#include <vector>
 #include <string>
-#include <map>
-#include "config.h"
 #include "socket.h"
 #include "base.h"
 
@@ -72,7 +68,7 @@ enum EventMask
 	/** Mask for all read events */
 	FD_WANT_READ_MASK = 0x0F,
 
-	/** Do not test this socket for writeability
+	/** Do not test this socket for writability
 	 */
 	FD_WANT_NO_WRITE = 0x10,
 	/** Give a write event at all times when writes will not block.
@@ -330,8 +326,6 @@ public:
 	 * failure (for example, you try and enable
 	 * epoll on a 2.4 linux kernel) then this
 	 * function may bail back to the shell.
-	 * @return void, but it is acceptable for this function to bail back to
-	 * the shell or operating system on fatal error.
 	 */
 	static void Init();
 
@@ -560,8 +554,6 @@ public:
 	 * allows for the socket engine to re-create its handle
 	 * after the daemon forks as the socket engine is created
 	 * long BEFORE the daemon forks.
-	 * @return void, but it is acceptable for this function to bail back to
-	 * the shell or operating system on fatal error.
 	 */
 	static void RecoverFromFork();
 
