@@ -5,17 +5,18 @@
  *   Copyright (C) 2019 linuxdaemon <linuxdaemon.irc@gmail.com>
  *   Copyright (C) 2013 Daniel Vassdal <shutter@canternet.org>
  *   Copyright (C) 2012-2016, 2018 Attila Molnar <attilamolnar@hush.com>
- *   Copyright (C) 2012-2013, 2016-2020 Sadie Powell <sadie@witchery.services>
- *   Copyright (C) 2012, 2018-2019 Robby <robby@chatbelgie.be>
+ *   Copyright (C) 2012-2013, 2016-2021 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2012, 2019 Robby <robby@chatbelgie.be>
  *   Copyright (C) 2012 DjSlash <djslash@djslash.org>
  *   Copyright (C) 2012 ChrisTX <xpipe@hotmail.de>
+ *   Copyright (C) 2011 jackmcbarn <jackmcbarn@inspircd.org>
  *   Copyright (C) 2009-2010 Daniel De Graaf <danieldg@inspircd.org>
  *   Copyright (C) 2009 Uli Schlachter <psychon@inspircd.org>
  *   Copyright (C) 2008 Thomas Stagner <aquanight@inspircd.org>
  *   Copyright (C) 2008 John Brooks <special@inspircd.org>
- *   Copyright (C) 2007-2009 Robin Burchell <robin+git@viroteck.net>
  *   Copyright (C) 2007, 2009 Dennis Friis <peavey@inspircd.org>
- *   Copyright (C) 2006-2008 Craig Edwards <brain@inspircd.org>
+ *   Copyright (C) 2006-2009 Robin Burchell <robin+git@viroteck.net>
+ *   Copyright (C) 2003-2008 Craig Edwards <brain@inspircd.org>
  *
  * This file is part of InspIRCd.  InspIRCd is free software: you can
  * redistribute it and/or modify it under the terms of the GNU General Public
@@ -60,8 +61,8 @@ enum RegistrationState {
 
 	REG_USER = 1,		/* Has sent USER */
 	REG_NICK = 2,		/* Has sent NICK */
-	REG_NICKUSER = 3, 	/* Bitwise combination of REG_NICK and REG_USER */
-	REG_ALL = 7	  	/* REG_NICKUSER plus next bit along */
+	REG_NICKUSER = 3,	/* Bitwise combination of REG_NICK and REG_USER */
+	REG_ALL = 7			/* REG_NICKUSER plus next bit along */
 };
 
 enum UserType {
@@ -70,84 +71,21 @@ enum UserType {
 	USERTYPE_SERVER = 3
 };
 
-/** Holds information relevant to &lt;connect allow&gt; and &lt;connect deny&gt; tags in the config file.
- */
-struct CoreExport ConnectClass : public refcountbase
+/** Represents \<connect> class tags from the server config */
+class CoreExport ConnectClass : public refcountbase
 {
+ public:
+ 	/** The synthesized (with all inheritance applied) config tag this class was read from. */
 	reference<ConfigTag> config;
-	/** Type of line, either CC_ALLOW or CC_DENY
-	 */
-	char type;
 
-	/** True if this class uses fake lag to manage flood, false if it kills */
-	bool fakelag;
-
-	/** Connect class name
-	 */
-	std::string name;
-
-	/** Max time to register the connection in seconds
-	 */
-	unsigned int registration_timeout;
-
-	/** Host mask for this line
-	 */
+	/** The hosts that this user can connect from as a string. */
 	std::string host;
 
-	/** Number of seconds between pings for this line
-	 */
-	unsigned int pingtime;
+	/** The hosts that this user can connect from as a vector. */
+	std::vector<std::string> hosts;
 
-	/** Maximum size of sendq for users in this class (bytes)
-	 * Users cannot send commands if they go over this limit
-	 */
-	unsigned long softsendqmax;
-
-	/** Maximum size of sendq for users in this class (bytes)
-	 * Users are killed if they go over this limit
-	 */
-	unsigned long hardsendqmax;
-
-	/** Maximum size of recvq for users in this class (bytes)
-	 */
-	unsigned long recvqmax;
-
-	/** Seconds worth of penalty before penalty system activates
-	 */
-	unsigned int penaltythreshold;
-
-	/** Maximum rate of commands (units: millicommands per second) */
-	unsigned int commandrate;
-
-	/** Local max when connecting by this connection class
-	 */
-	unsigned long maxlocal;
-
-	/** Global max when connecting by this connection class
-	 */
-	unsigned long maxglobal;
-
-	/** True if max connections for this class is hit and a warning is wanted
-	 */
-	bool maxconnwarn;
-
-	/** Max channels for this class
-	 */
-	unsigned int maxchans;
-
-	/** How many users may be in this connect class before they are refused?
-	 * (0 = no limit = default)
-	 */
-	unsigned long limit;
-
-	/** If set to true, no user DNS lookups are to be performed
-	 */
-	bool resolvehostnames;
-
-	/**
-	 * If non-empty the server ports which this user has to be using
-	 */
-	insp::flat_set<int> ports;
+	/** The name of this connect class. */
+	std::string name;
 
 	/** If non-empty then the password a user must specify in PASS to be assigned to this class. */
 	std::string password;
@@ -155,18 +93,74 @@ struct CoreExport ConnectClass : public refcountbase
 	/** If non-empty then the hash algorithm that the password field is hashed with. */
 	std::string passwordhash;
 
-	/** Create a new connect class with no settings.
-	 */
+	/** If non-empty then the server ports which a user has to be connecting on. */
+	insp::flat_set<int> ports;
+
+	/** The type of class this. */
+	char type;
+
+	/** Whether fake lag is used by this class. */
+	bool fakelag:1;
+
+	/** Whether to warn server operators about the limit for this class being reached. */
+	bool maxconnwarn:1;
+
+	/** Whether the DNS hostnames of users in this class should be resolved. */
+	bool resolvehostnames:1;
+
+	/** Whether this class is for a shared host where the username (ident) uniquely identifies users. */
+	bool uniqueusername:1;
+
+	/** The maximum number of channels that users in this class can join. */
+	unsigned int maxchans;
+
+	/** The amount of penalty that a user in this class can have before the penalty system activates. */
+	unsigned int penaltythreshold;
+
+	/** The number of seconds between keepalive checks for idle clients in this class. */
+	unsigned int pingtime;
+
+	/** The number of seconds that connecting users have to register within in this class. */
+	unsigned int registration_timeout;
+
+	/** Maximum rate of commands (units: millicommands per second) */
+	unsigned int commandrate;
+
+	/** The maximum number of bytes that users in this class can have in their send queue before they are disconnected. */
+	unsigned long hardsendqmax;
+
+	/** The maximum number of users in this class that can connect to the local server from one host. */
+	unsigned long limit;
+
+	/** The maximum number of users in this class that can connect to the entire network from one host. */
+	unsigned long maxglobal;
+
+	/** The maximum number of users that can be in this class on the local server. */
+	unsigned long maxlocal;
+
+	/** The maximum number of bytes that users in this class can have in their receive queue before they are disconnected. */
+	unsigned long recvqmax;
+
+	/** The maximum number of bytes that users in this class can have in their send queue before their commands stop being processed. */
+	unsigned long softsendqmax;
+
+	/** Creates a new connect class from a config tag */
 	ConnectClass(ConfigTag* tag, char type, const std::string& mask);
-	/** Create a new connect class with inherited settings.
-	 */
+
+	/** Creates a new connect class with a parent from a config tag. */
 	ConnectClass(ConfigTag* tag, char type, const std::string& mask, const ConnectClass& parent);
 
-	/** Update the settings in this block to match the given block */
+	/** Update the settings in this block to match the given class */
 	void Update(const ConnectClass* newSettings);
 
-	const std::string& GetName() { return name; }
-	const std::string& GetHost() { return host; }
+	/** Retrieves the name of this connect class. */
+	const std::string& GetName() const { return name; }
+
+	/** Retrieves the hosts that this user can connect from as a string. */
+	const std::string& GetHost() const { return host; }
+
+	/** Retrieves the hosts that this user can connect from as a vector. */
+	const std::vector<std::string>& GetHosts() const { return hosts; }
 
 	/** Returns the registration timeout
 	 */
@@ -231,6 +225,9 @@ struct CoreExport ConnectClass : public refcountbase
 	}
 };
 
+/** An id that can be used to mark the last message sent. */
+typedef unsigned int already_sent_t;
+
 /** Holds all information about a user
  * This class stores all information about a user connected to the irc server. Everything about a
  * connection is stored here primarily, from the user's socket ID (file descriptor) through to the
@@ -239,19 +236,19 @@ struct CoreExport ConnectClass : public refcountbase
 class CoreExport User : public Extensible
 {
  private:
-	/** Cached nick!ident@dhost value using the displayed hostname
+	/** Cached nick!ident\@dhost value using the displayed hostname
 	 */
 	std::string cached_fullhost;
 
-	/** Cached ident@ip value using the real IP address
+	/** Cached ident\@ip value using the real IP address
 	 */
 	std::string cached_hostip;
 
-	/** Cached ident@realhost value using the real hostname
+	/** Cached ident\@realhost value using the real hostname
 	 */
 	std::string cached_makehost;
 
-	/** Cached nick!ident@realhost value using the real hostname
+	/** Cached nick!ident\@realhost value using the real hostname
 	 */
 	std::string cached_fullrealhost;
 
@@ -366,6 +363,9 @@ class CoreExport User : public Extensible
 	 */
 	unsigned int quitting:1;
 
+	/** Whether the ident field uniquely identifies this user on their origin host. */
+	bool uniqueusername:1;
+
 	/** What type of user is this? */
 	const unsigned int usertype:2;
 
@@ -379,6 +379,9 @@ class CoreExport User : public Extensible
 	 */
 	const std::string& GetHost(bool uncloak) const;
 
+	/** Retrieves the username which should be included in bans for this user. */
+	const std::string& GetBanIdent() const;
+
 	/** Retrieves this user's displayed hostname. */
 	const std::string& GetDisplayedHost() const;
 
@@ -465,7 +468,7 @@ class CoreExport User : public Extensible
 	void SetMode(ModeHandler* mh, bool value);
 	void SetMode(ModeHandler& mh, bool value) { SetMode(&mh, value); }
 
-	/** Returns true or false for if a user can execute a privilaged oper command.
+	/** Returns true or false for if a user can execute a privileged oper command.
 	 * This is done by looking up their oper type from User::oper, then referencing
 	 * this to their oper classes and checking the commands they can execute.
 	 * @param command A command (should be all CAPS)
@@ -477,7 +480,7 @@ class CoreExport User : public Extensible
 	 * This is used to check whether or not users may perform certain actions which admins may not wish to give to
 	 * all operators, yet are not commands. An example might be oper override, mass messaging (/notice $*), etc.
 	 *
-	 * @param privstr The priv to chec, e.g. "users/override/topic". These are loaded free-form from the config file.
+	 * @param privstr The priv to check, e.g. "users/override/topic". These are loaded free-form from the config file.
 	 * @return True if this user has the permission in question.
 	 */
 	virtual bool HasPrivPermission(const std::string& privstr);
@@ -646,7 +649,7 @@ class CoreExport User : public Extensible
 	 * @param include_self True to include this user in the set of neighbors, false otherwise.
 	 * Modules may override this. Has no effect if this user is not local.
 	 */
-	void ForEachNeighbor(ForEachNeighborHandler& handler, bool include_self = true);
+	already_sent_t ForEachNeighbor(ForEachNeighborHandler& handler, bool include_self = true);
 
 	/** Return true if the user shares at least one channel with another user
 	 * @param other The other user to compare the channel list against
@@ -668,7 +671,7 @@ class CoreExport User : public Extensible
 
 	/** Change the ident (username) of a user.
 	 * ALWAYS use this function, rather than writing User::ident directly,
-	 * as this triggers module events allowing the change to be syncronized to
+	 * as this triggers module events allowing the change to be synchronized to
 	 * remote servers.
 	 * @param newident The new ident to set
 	 * @return True if the change succeeded, false if it didn't
@@ -708,7 +711,7 @@ class CoreExport User : public Extensible
 class CoreExport UserIOHandler : public StreamSocket
 {
  private:
-	 size_t checked_until;
+	size_t checked_until;
  public:
 	LocalUser* const user;
 	UserIOHandler(LocalUser* me)
@@ -734,8 +737,6 @@ class CoreExport UserIOHandler : public StreamSocket
 	void SwapInternals(UserIOHandler& other);
 };
 
-typedef unsigned int already_sent_t;
-
 class CoreExport LocalUser : public User, public insp::intrusive_list_node<LocalUser>
 {
 	/** Add a serialized message to the send queue of the user.
@@ -846,7 +847,6 @@ class CoreExport LocalUser : public User, public insp::intrusive_list_node<Local
 
 	/** Set the connect class to which this user belongs to.
 	 * @param explicit_name Set this string to tie the user to a specific class name. Otherwise, the class is fitted by checking \<connect> tags from the configuration file.
-	 * @return A reference to this user's current connect class.
 	 */
 	void SetClass(const std::string &explicit_name = "");
 
@@ -860,7 +860,7 @@ class CoreExport LocalUser : public User, public insp::intrusive_list_node<Local
 	 */
 	void WriteRemoteNotice(const std::string& text) CXX11_OVERRIDE;
 
-	/** Returns true or false for if a user can execute a privilaged oper command.
+	/** Returns true or false for if a user can execute a privileged oper command.
 	 * This is done by looking up their oper type from User::oper, then referencing
 	 * this to their oper classes and checking the commands they can execute.
 	 * @param command A command (should be all CAPS)
@@ -872,7 +872,7 @@ class CoreExport LocalUser : public User, public insp::intrusive_list_node<Local
 	 * This is used to check whether or not users may perform certain actions which admins may not wish to give to
 	 * all operators, yet are not commands. An example might be oper override, mass messaging (/notice $*), etc.
 	 *
-	 * @param privstr The priv to chec, e.g. "users/override/topic". These are loaded free-form from the config file.
+	 * @param privstr The priv to check, e.g. "users/override/topic". These are loaded free-form from the config file.
 	 * @return True if this user has the permission in question.
 	 */
 	bool HasPrivPermission(const std::string& privstr) CXX11_OVERRIDE;
