@@ -1,13 +1,14 @@
 /*
  * InspIRCd -- Internet Relay Chat Daemon
  *
+ *   Copyright (C) 2021 Herman <GermanAizek@yandex.ru>
  *   Copyright (C) 2014, 2018-2020 Sadie Powell <sadie@witchery.services>
  *   Copyright (C) 2012-2016, 2018 Attila Molnar <attilamolnar@hush.com>
  *   Copyright (C) 2012 Robby <robby@chatbelgie.be>
  *   Copyright (C) 2009-2010 Daniel De Graaf <danieldg@inspircd.org>
  *   Copyright (C) 2007-2009 Robin Burchell <robin+git@viroteck.net>
  *   Copyright (C) 2007 Dennis Friis <peavey@inspircd.org>
- *   Copyright (C) 2006-2008, 2010 Craig Edwards <brain@inspircd.org>
+ *   Copyright (C) 2005-2008, 2010 Craig Edwards <brain@inspircd.org>
  *
  * This file is part of InspIRCd.  InspIRCd is free software: you can
  * redistribute it and/or modify it under the terms of the GNU General Public
@@ -122,22 +123,22 @@ Command* CommandParser::GetHandler(const std::string &commandname)
 
 CmdResult CommandParser::CallHandler(const std::string& commandname, const CommandBase::Params& parameters, User* user, Command** cmd)
 {
-	CommandMap::iterator n = cmdlist.find(commandname);
-
-	if (n != cmdlist.end())
+	/* find the command, check it exists */
+	Command* handler = GetHandler(commandname);
+	if (handler)
 	{
-		if ((!parameters.empty()) && (parameters.back().empty()) && (!n->second->allow_empty_last_param))
+		if ((!parameters.empty()) && (parameters.back().empty()) && (!handler->allow_empty_last_param))
 			return CMD_INVALID;
 
-		if (parameters.size() >= n->second->min_params)
+		if (parameters.size() >= handler->min_params)
 		{
 			bool bOkay = false;
 
-			if (IS_LOCAL(user) && n->second->flags_needed)
+			if (IS_LOCAL(user) && handler->flags_needed)
 			{
 				/* if user is local, and flags are needed .. */
 
-				if (user->IsModeSet(n->second->flags_needed))
+				if (user->IsModeSet(handler->flags_needed))
 				{
 					/* if user has the flags, and now has the permissions, go ahead */
 					if (user->HasCommandPermission(commandname))
@@ -153,10 +154,10 @@ CmdResult CommandParser::CallHandler(const std::string& commandname, const Comma
 			if (bOkay)
 			{
 				if (cmd)
-					*cmd = n->second;
+					*cmd = handler;
 
 				ClientProtocol::TagMap tags;
-				return n->second->Handle(user, CommandBase::Params(parameters, tags));
+				return handler->Handle(user, CommandBase::Params(parameters, tags));
 			}
 		}
 	}
