@@ -1,7 +1,7 @@
 /*
  * InspIRCd -- Internet Relay Chat Daemon
  *
- *   Copyright (C) 2017-2018 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2017-2018, 2021 Sadie Powell <sadie@witchery.services>
  *   Copyright (C) 2017 B00mX0r <b00mx0r@aureus.pw>
  *   Copyright (C) 2013-2014, 2016 Attila Molnar <attilamolnar@hush.com>
  *   Copyright (C) 2012, 2019 Robby <robby@chatbelgie.be>
@@ -73,7 +73,7 @@ CmdResult CommandKick::Handle(User* user, const Params& parameters)
 
 		if (u->server->IsULine())
 		{
-			user->WriteNumeric(ERR_CHANOPRIVSNEEDED, c->name, "You may not kick a U-lined client");
+			user->WriteNumeric(ERR_RESTRICTED, c->name, "You may not kick a U-lined client");
 			return CMD_FAILURE;
 		}
 	}
