@@ -1,7 +1,7 @@
 /*
  * InspIRCd -- Internet Relay Chat Daemon
  *
- *   Copyright (C) 2017, 2019 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2017, 2019, 2021 Sadie Powell <sadie@witchery.services>
  *   Copyright (C) 2014 Attila Molnar <attilamolnar@hush.com>
  *   Copyright (C) 2012 Robby <robby@chatbelgie.be>
  *   Copyright (C) 2009 Daniel De Graaf <danieldg@inspircd.org>
@@ -41,8 +41,21 @@ bool ModeChannelLimit::ResolveModeConflict(std::string &their_param, const std::
 ModeAction ModeChannelLimit::OnSet(User* user, Channel* chan, std::string& parameter)
 {
 	size_t limit = ConvToNum<size_t>(parameter);
-	if (limit < minlimit)
-		return MODEACTION_DENY;
+	if (limit < minlimit || limit > INTPTR_MAX)
+	{
+		if (IS_LOCAL(user))
+		{
+			// If the setter is local then we can safely just reject this here.
+			user->WriteNumeric(Numerics::InvalidModeParameter(chan, this, parameter));
+			return MODEACTION_DENY;
+		}
+		else
+		{
+			// If the setter is remote we *must* set the mode to avoid a desync
+			// so instead clamp it to the allowed range instead.
+			limit = std::min<size_t>(std::max(limit, minlimit), INTPTR_MAX);
+		}
+	}
 
 	ext.set(chan, limit);
 	return MODEACTION_ALLOW;
@@ -50,5 +63,5 @@ ModeAction ModeChannelLimit::OnSet(User* user, Channel* chan, std::string& param
 
 void ModeChannelLimit::SerializeParam(Channel* chan, intptr_t n, std::string& out)
 {
-	out += ConvToStr(n);
+	out += ConvToStr(static_cast<size_t>(n));
 }
