@@ -2,9 +2,9 @@
  * InspIRCd -- Internet Relay Chat Daemon
  *
  *   Copyright (C) 2019 Robby <robby@chatbelgie.be>
- *   Copyright (C) 2015, 2017-2020 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2015, 2017-2021 Sadie Powell <sadie@witchery.services>
  *   Copyright (C) 2013-2016 Attila Molnar <attilamolnar@hush.com>
- *   Copyright (C) 2013, 2015-2016 Adam <Adam@anope.org>
+ *   Copyright (C) 2013, 2015-2016, 2021 Adam <Adam@anope.org>
  *
  * This file is part of InspIRCd.  InspIRCd is free software: you can
  * redistribute it and/or modify it under the terms of the GNU General Public
@@ -211,7 +211,13 @@ class Packet : public Query
 				break;
 			}
 			default:
+			{
+				if (pos + rdlength > input_size)
+					throw Exception("Unable to skip resource record");
+
+				pos += rdlength;
 				break;
+			}
 		}
 
 		if (!record.name.empty() && !record.rdata.empty())
@@ -273,7 +279,7 @@ class Packet : public Query
 	unsigned short Pack(unsigned char* output, unsigned short output_size)
 	{
 		if (output_size < HEADER_LENGTH)
-			throw Exception("Unable to pack packet");
+			throw Exception("Unable to pack oversized packet header");
 
 		unsigned short pos = 0;
 
@@ -296,7 +302,8 @@ class Packet : public Query
 			if (q.type == QUERY_PTR)
 			{
 				irc::sockets::sockaddrs ip;
-				irc::sockets::aptosa(q.name, 0, ip);
+				if (!irc::sockets::aptosa(q.name, 0, ip))
+					throw Exception("Unable to pack packet with malformed IP for PTR lookup");
 
 				if (q.name.find(':') != std::string::npos)
 				{
@@ -327,7 +334,7 @@ class Packet : public Query
 			this->PackName(output, output_size, pos, q.name);
 
 			if (pos + 4 >= output_size)
-				throw Exception("Unable to pack packet");
+				throw Exception("Unable to pack oversized packet body");
 
 			short s = htons(q.type);
 			memcpy(&output[pos], &s, 2);
@@ -423,6 +430,7 @@ class MyManager : public Manager, public Timer, public EventHandler
 	~MyManager()
 	{
 		// Ensure Process() will fail for new requests
+		Close();
 		unloading = true;
 
 		for (unsigned int i = 0; i <= MAX_REQUEST_ID; ++i)
@@ -439,11 +447,32 @@ class MyManager : public Manager, public Timer, public EventHandler
 		}
 	}
 
+	void Close()
+	{
+		// Shutdown the socket if it exists.
+		if (HasFd())
+		{
+			SocketEngine::Shutdown(this, 2);
+			SocketEngine::Close(this);
+		}
+
+		// Remove all entries from the cache.
+		cache.clear();
+	}
+
 	void Process(DNS::Request* req) CXX11_OVERRIDE
 	{
 		if ((unloading) || (req->creator->dying))
 			throw Exception("Module is being unloaded");
 
+		if (!HasFd())
+		{
+			Query rr(req->question);
+			rr.error = ERROR_DISABLED;
+			req->OnError(&rr);
+			return;
+		}
+
 		ServerInstance->Logs->Log(MODNAME, LOG_DEBUG, "Processing request to lookup " + req->question.name + " of type " + ConvToStr(req->question.type) + " to " + this->myserver.addr());
 
 		/* Create an id */
@@ -533,6 +562,8 @@ class MyManager : public Manager, public Timer, public EventHandler
 			case ERROR_DOMAIN_NOT_FOUND:
 			case ERROR_NO_RECORDS:
 				return "Domain not found";
+			case ERROR_DISABLED:
+				return "DNS lookups are disabled";
 			case ERROR_NONE:
 			case ERROR_UNKNOWN:
 			default:
@@ -703,23 +734,15 @@ class MyManager : public Manager, public Timer, public EventHandler
 
 	void Rehash(const std::string& dnsserver, std::string sourceaddr, unsigned int sourceport)
 	{
-		if (this->HasFd())
-		{
-			SocketEngine::Shutdown(this, 2);
-			SocketEngine::Close(this);
-
-			// Remove all entries from the cache.
-			cache.clear();
-		}
-
 		irc::sockets::aptosa(dnsserver, DNS::PORT, myserver);
 
 		/* Initialize mastersocket */
+		Close();
 		int s = socket(myserver.family(), SOCK_DGRAM, 0);
 		this->SetFd(s);
 
 		/* Have we got a socket? */
-		if (this->GetFd() != -1)
+		if (this->HasFd())
 		{
 			SocketEngine::SetReuse(s);
 			SocketEngine::NonBlocking(s);
@@ -832,13 +855,25 @@ class ModuleDNS : public Module
 
 	void ReadConfig(ConfigStatus& status) CXX11_OVERRIDE
 	{
-		std::string oldserver = DNSServer;
-		const std::string oldip = SourceIP;
-		const unsigned int oldport = SourcePort;
-
 		ConfigTag* tag = ServerInstance->Config->ConfValue("dns");
+		if (!tag->getBool("enabled", true))
+		{
+			// Clear these so they get reset if DNS is enabled again.
+			DNSServer.clear();
+			SourceIP.clear();
+			SourcePort = 0;
+
+			this->manager.Close();
+			return;
+		}
+
+		const std::string oldserver = DNSServer;
 		DNSServer = tag->getString("server");
+
+		const std::string oldip = SourceIP;
 		SourceIP = tag->getString("sourceip");
+
+		const unsigned int oldport = SourcePort;
 		SourcePort = tag->getUInt("sourceport", 0, 0, UINT16_MAX);
 
 		if (DNSServer.empty())
