@@ -57,7 +57,7 @@ CmdResult CommandMotd::Handle(User* user, const Params& parameters)
 		return CMD_SUCCESS;
 	}
 
-	user->WriteRemoteNumeric(RPL_MOTDSTART, InspIRCd::Format("%s message of the day", ServerInstance->Config->ServerName.c_str()));
+	user->WriteRemoteNumeric(RPL_MOTDSTART, InspIRCd::Format("%s message of the day", ServerInstance->Config->GetServerName().c_str()));
 
 	for (file_cache::iterator i = motd->second.begin(); i != motd->second.end(); i++)
 		user->WriteRemoteNumeric(RPL_MOTD, InspIRCd::Format(" %s", i->c_str()));
