@@ -1,12 +1,12 @@
 /*
  * InspIRCd -- Internet Relay Chat Daemon
  *
- *   Copyright (C) 2017-2020 Sadie Powell <sadie@witchery.services>
- *   Copyright (C) 2013, 2017-2018 Attila Molnar <attilamolnar@hush.com>
+ *   Copyright (C) 2017-2021 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2013-2014, 2018 Attila Molnar <attilamolnar@hush.com>
  *   Copyright (C) 2012, 2019 Robby <robby@chatbelgie.be>
  *   Copyright (C) 2009 Daniel De Graaf <danieldg@inspircd.org>
  *   Copyright (C) 2007 Dennis Friis <peavey@inspircd.org>
- *   Copyright (C) 2006-2007, 2010 Craig Edwards <brain@inspircd.org>
+ *   Copyright (C) 2006-2008, 2010 Craig Edwards <brain@inspircd.org>
  *
  * This file is part of InspIRCd.  InspIRCd is free software: you can
  * redistribute it and/or modify it under the terms of the GNU General Public
@@ -24,11 +24,6 @@
 
 #include "inspircd.h"
 
-enum
-{
-	// From RFC 2812.
-	ERR_NOSUCHSERVICE = 408
-};
 
 class MessageDetailsImpl : public MessageDetails
 {
@@ -107,7 +102,7 @@ namespace
 		FIRST_MOD_RESULT(OnUserPreMessage, modres, (source, msgtarget, msgdetails));
 		if (modres == MOD_RES_DENY)
 		{
-			// Inform modules that a module blocked the mssage.
+			// Inform modules that a module blocked the message.
 			FOREACH_MOD(OnUserMessageBlocked, (source, msgtarget, msgdetails));
 			return false;
 		}
@@ -228,7 +223,7 @@ class CommandMessage : public Command
 			{
 				// The target is a user on a specific server (e.g. jto@tolsun.oulu.fi).
 				target = ServerInstance->FindNickOnly(parameters[0].substr(0, targetserver - parameters[0].c_str()));
-				if (target && strcasecmp(target->server->GetName().c_str(), targetserver + 1))
+				if (target && strcasecmp(target->server->GetPublicName().c_str(), targetserver + 1))
 					target = NULL;
 			}
 			else
@@ -303,15 +298,26 @@ class CommandMessage : public Command
 		if (parameters[0][0] == '$')
 			return HandleServerTarget(user, parameters);
 
-		// If the message begins with a status character then look it up.
+		// If the message begins with one or more status characters then look them up.
 		const char* target = parameters[0].c_str();
-		PrefixMode* pmh = ServerInstance->Modes->FindPrefix(target[0]);
-		if (pmh)
-			target++;
+		PrefixMode* targetpfx = NULL;
+		for (PrefixMode* pfx; (pfx = ServerInstance->Modes->FindPrefix(target[0])); ++target)
+		{
+			// We want the lowest ranked prefix specified.
+			if (!targetpfx || pfx->GetPrefixRank() < targetpfx->GetPrefixRank())
+				targetpfx = pfx;
+		}
+
+		if (!target[0])
+		{
+			// The target consisted solely of prefix modes.
+			user->WriteNumeric(ERR_NORECIPIENT, "No recipient given");
+			return CMD_FAILURE;
+		}
 
 		// The target is a channel name.
 		if (*target == '#')
-			return HandleChannelTarget(user, parameters, target, pmh);
+			return HandleChannelTarget(user, parameters, target, targetpfx);
 
 		// The target is a nickname.
 		return HandleUserTarget(user, parameters);
@@ -352,7 +358,7 @@ class CommandSQuery : public SplitCommand
 		{
 			// The target is a user on a specific server (e.g. jto@tolsun.oulu.fi).
 			target = ServerInstance->FindNickOnly(parameters[0].substr(0, targetserver - parameters[0].c_str()));
-			if (target && strcasecmp(target->server->GetName().c_str(), targetserver + 1))
+			if (target && strcasecmp(target->server->GetPublicName().c_str(), targetserver + 1))
 				target = NULL;
 		}
 		else
