@@ -3,13 +3,13 @@
  *
  *   Copyright (C) 2017 B00mX0r <b00mx0r@aureus.pw>
  *   Copyright (C) 2014, 2016 Attila Molnar <attilamolnar@hush.com>
- *   Copyright (C) 2013, 2016, 2018 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2013, 2016, 2018, 2021 Sadie Powell <sadie@witchery.services>
  *   Copyright (C) 2012 Robby <robby@chatbelgie.be>
  *   Copyright (C) 2009-2010 Daniel De Graaf <danieldg@inspircd.org>
  *   Copyright (C) 2009 Uli Schlachter <psychon@inspircd.org>
  *   Copyright (C) 2007-2008 Robin Burchell <robin+git@viroteck.net>
- *   Copyright (C) 2007, 2010 Craig Edwards <brain@inspircd.org>
  *   Copyright (C) 2007 Dennis Friis <peavey@inspircd.org>
+ *   Copyright (C) 2006-2007, 2010 Craig Edwards <brain@inspircd.org>
  *
  * This file is part of InspIRCd.  InspIRCd is free software: you can
  * redistribute it and/or modify it under the terms of the GNU General Public
@@ -29,7 +29,7 @@
 #include "core_user.h"
 
 CommandNick::CommandNick(Module* parent)
-	: SplitCommand(parent, "NICK", 1, 1)
+	: SplitCommand(parent, "NICK", 1)
 {
 	works_before_reg = true;
 	syntax = "<newnick>";
@@ -43,7 +43,6 @@ CommandNick::CommandNick(Module* parent)
  */
 CmdResult CommandNick::HandleLocal(LocalUser* user, const Params& parameters)
 {
-	std::string oldnick = user->nick;
 	std::string newnick = parameters[0];
 
 	// anything except the initial NICK gets a flood penalty
