@@ -1,7 +1,7 @@
 /*
  * InspIRCd -- Internet Relay Chat Daemon
  *
- *   Copyright (C) 2017, 2020 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2017, 2020-2021 Sadie Powell <sadie@witchery.services>
  *   Copyright (C) 2013, 2016 Attila Molnar <attilamolnar@hush.com>
  *   Copyright (C) 2012, 2019 Robby <robby@chatbelgie.be>
  *   Copyright (C) 2009 Daniel De Graaf <danieldg@inspircd.org>
@@ -104,6 +104,13 @@ std::string ModeUserServerNoticeMask::ProcessNoticeMasks(User* user, const std::
 						user->WriteNumeric(ERR_UNKNOWNSNOMASK, *i, "is an unknown snomask character");
 						continue;
 					}
+					else if (!user->IsOper())
+					{
+						user->WriteNumeric(ERR_NOPRIVILEGES, InspIRCd::Format("Permission Denied - Only operators may %sset snomask %c",
+							adding ? "" : "un", *i));
+						continue;
+
+					}
 					else if (!user->HasSnomaskPermission(*i))
 					{
 						user->WriteNumeric(ERR_NOPRIVILEGES, InspIRCd::Format("Permission Denied - Oper type %s does not have access to snomask %c",
