@@ -2,9 +2,9 @@
  * InspIRCd -- Internet Relay Chat Daemon
  *
  *   Copyright (C) 2019 Matt Schatz <genius3000@g3k.solutions>
+ *   Copyright (C) 2018, 2021 Sadie Powell <sadie@witchery.services>
  *   Copyright (C) 2018 linuxdaemon <linuxdaemon.irc@gmail.com>
- *   Copyright (C) 2018 Sadie Powell <sadie@witchery.services>
- *   Copyright (C) 2012, 2018-2019 Robby <robby@chatbelgie.be>
+ *   Copyright (C) 2012, 2019 Robby <robby@chatbelgie.be>
  *   Copyright (C) 2012, 2014 Attila Molnar <attilamolnar@hush.com>
  *   Copyright (C) 2009 Uli Schlachter <psychon@inspircd.org>
  *   Copyright (C) 2009 Daniel De Graaf <danieldg@inspircd.org>
@@ -49,9 +49,9 @@ CmdResult CommandKline::Handle(User* user, const Params& parameters)
 		User* find = ServerInstance->FindNick(target);
 		if ((find) && (find->registered == REG_ALL))
 		{
-			ih.first = "*";
+			ih.first = find->GetBanIdent();
 			ih.second = find->GetIPString();
-			target = std::string("*@") + find->GetIPString();
+			target = ih.first + "@" + ih.second;
 		}
 		else
 			ih = ServerInstance->XLines->IdentSplit(target);
