@@ -2,9 +2,9 @@
  * InspIRCd -- Internet Relay Chat Daemon
  *
  *   Copyright (C) 2019 linuxdaemon <linuxdaemon.irc@gmail.com>
+ *   Copyright (C) 2019 Robby <robby@chatbelgie.be>
  *   Copyright (C) 2019 Matt Schatz <genius3000@g3k.solutions>
- *   Copyright (C) 2018-2019 Robby <robby@chatbelgie.be>
- *   Copyright (C) 2017-2020 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2017-2021 Sadie Powell <sadie@witchery.services>
  *   Copyright (C) 2014, 2016 Attila Molnar <attilamolnar@hush.com>
  *
  * This file is part of InspIRCd.  InspIRCd is free software: you can
@@ -77,7 +77,7 @@ class CoreModXLine : public Module
 		user->CheckLines(true);
 	}
 
-	void OnChangeRealHost(User* user, const std::string& newhost) CXX11_OVERRIDE
+	void OnPostChangeRealHost(User* user) CXX11_OVERRIDE
 	{
 		LocalUser* luser = IS_LOCAL(user);
 		if (!luser || luser->quitting)
@@ -98,7 +98,7 @@ class CoreModXLine : public Module
 		// A Q-line matched the new nick, tell opers if the user is registered
 		if (user->registered == REG_ALL)
 		{
-			ServerInstance->SNO->WriteGlobalSno('a', "Q-lined nickname %s from %s: %s",
+			ServerInstance->SNO->WriteGlobalSno('x', "Q-lined nickname %s from %s: %s",
 				newnick.c_str(), user->GetFullRealHost().c_str(), xline->reason.c_str());
 		}
 
