@@ -1,21 +1,22 @@
 /*
  * InspIRCd -- Internet Relay Chat Daemon
  *
+ *   Copyright (C) 2021 Valentin Lorentz <progval+git@progval.net>
  *   Copyright (C) 2020 Matt Schatz <genius3000@g3k.solutions>
- *   Copyright (C) 2018 Chris Novakovic <chrisnovakovic@users.noreply.github.com>
- *   Copyright (C) 2013, 2017-2020 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2018 Chris Novakovic
+ *   Copyright (C) 2013, 2017-2021 Sadie Powell <sadie@witchery.services>
  *   Copyright (C) 2013 Adam <Adam@anope.org>
  *   Copyright (C) 2012-2014, 2016, 2018 Attila Molnar <attilamolnar@hush.com>
- *   Copyright (C) 2012 William Pitcock <nenolod@dereferenced.org>
+ *   Copyright (C) 2012-2013 ChrisTX <xpipe@hotmail.de>
  *   Copyright (C) 2012 Robby <robby@chatbelgie.be>
- *   Copyright (C) 2012 ChrisTX <xpipe@hotmail.de>
+ *   Copyright (C) 2012 Ariadne Conill <ariadne@dereferenced.org>
  *   Copyright (C) 2009-2010 Daniel De Graaf <danieldg@inspircd.org>
- *   Copyright (C) 2009 Uli Schlachter <psychon@inspircd.org>
+ *   Copyright (C) 2008-2009 Uli Schlachter <psychon@inspircd.org>
  *   Copyright (C) 2008 Thomas Stagner <aquanight@inspircd.org>
- *   Copyright (C) 2007-2008, 2010 Craig Edwards <brain@inspircd.org>
  *   Copyright (C) 2007-2008 Robin Burchell <robin+git@viroteck.net>
- *   Copyright (C) 2007 Oliver Lupton <om@inspircd.org>
  *   Copyright (C) 2007 Dennis Friis <peavey@inspircd.org>
+ *   Copyright (C) 2006-2007 Oliver Lupton <om@inspircd.org>
+ *   Copyright (C) 2005-2010 Craig Edwards <brain@inspircd.org>
  *
  * This file is part of InspIRCd.  InspIRCd is free software: you can
  * redistribute it and/or modify it under the terms of the GNU General Public
@@ -41,9 +42,11 @@
 	#include <pwd.h> // setuid
 	#include <grp.h> // setgid
 #else
-	WORD g_wOriginalColors;
-	WORD g_wBackgroundColor;
-	HANDLE g_hStdout;
+	/** Manages formatting lines written to stderr on Windows. */
+	WindowsStream StandardError(STD_ERROR_HANDLE);
+
+	/** Manages formatting lines written to stdout on Windows. */
+	WindowsStream StandardOutput(STD_OUTPUT_HANDLE);
 #endif
 
 #include <fstream>
@@ -322,7 +325,7 @@ namespace
 
 				default:
 					// An unknown option was specified.
-					std::cout << con_red << "Error:" <<  con_reset << " unknown option '" << argv[optind] << "'." << std::endl
+					std::cout << con_red << "Error:" <<  con_reset << " unknown option '" << argv[optind-1] << "'." << std::endl
 						<< con_bright << "Usage: " << con_reset << argv[0] << " [--config <file>] [--debug] [--nofork] [--nolog]" << std::endl
 						<< std::string(strlen(argv[0]) + 8, ' ') << "[--nopid] [--runasroot] [--version]" << std::endl;
 					ServerInstance->Exit(EXIT_STATUS_ARGV);
@@ -332,7 +335,7 @@ namespace
 
 		if (do_version)
 		{
-			std::cout << std::endl << INSPIRCD_VERSION << std::endl;
+			std::cout << INSPIRCD_VERSION << std::endl;
 			ServerInstance->Exit(EXIT_STATUS_NOERROR);
 		}
 
@@ -445,7 +448,7 @@ void InspIRCd::WritePID(const std::string& filename, bool exitonfail)
 		return;
 	}
 
-	std::string fname = ServerInstance->Config->Paths.PrependData(filename.empty() ? "inspircd.pid" : filename);
+	std::string fname = ServerInstance->Config->Paths.PrependRuntime(filename.empty() ? "inspircd.pid" : filename);
 	std::ofstream outfile(fname.c_str());
 	if (outfile.is_open())
 	{
@@ -490,22 +493,7 @@ InspIRCd::InspIRCd(int argc, char** argv)
 
 	this->Config->cmdline.argv = argv;
 	this->Config->cmdline.argc = argc;
-
-#ifdef _WIN32
-	// Initialize the console values
-	g_hStdout = GetStdHandle(STD_OUTPUT_HANDLE);
-	CONSOLE_SCREEN_BUFFER_INFO bufinf;
-	if(GetConsoleScreenBufferInfo(g_hStdout, &bufinf))
-	{
-		g_wOriginalColors = bufinf.wAttributes & 0x00FF;
-		g_wBackgroundColor = bufinf.wAttributes & 0x00F0;
-	}
-	else
-	{
-		g_wOriginalColors = FOREGROUND_RED|FOREGROUND_BLUE|FOREGROUND_GREEN;
-		g_wBackgroundColor = 0;
-	}
-#endif
+	ParseOptions();
 
 	{
 		ServiceProvider* provs[] =
@@ -521,10 +509,10 @@ InspIRCd::InspIRCd(int argc, char** argv)
 		<< "See " << con_green << "/INFO" << con_reset << " for contributors & authors" << std::endl
 		<< std::endl;
 
-	ParseOptions();
 	if (Config->cmdline.forcedebug)
 	{
-		FileWriter* fw = new FileWriter(stdout, 1);
+		FILE* newstdout = fdopen(dup(STDOUT_FILENO), "w");
+		FileWriter* fw = new FileWriter(newstdout, 1);
 		FileLogStream* fls = new FileLogStream(LOG_RAWIO, fw);
 		Logs->AddLogTypes("*", fls, true);
 	}
