@@ -4,7 +4,7 @@
  *   Copyright (C) 2020 Matt Schatz <genius3000@g3k.solutions>
  *   Copyright (C) 2019 nia <nia@netbsd.org>
  *   Copyright (C) 2019 iwalkalone <iwalkalone69@gmail.com>
- *   Copyright (C) 2013, 2017-2020 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2013, 2017-2021 Sadie Powell <sadie@witchery.services>
  *   Copyright (C) 2013 Daniel Vassdal <shutter@canternet.org>
  *   Copyright (C) 2013 Adam <Adam@anope.org>
  *   Copyright (C) 2012-2016, 2018 Attila Molnar <attilamolnar@hush.com>
@@ -55,7 +55,7 @@ Version::Version(const std::string &desc, int flags, const std::string& linkdata
 {
 }
 
-// These declarations define the behavours of the base class Module (which does nothing at all)
+// These declarations define the behaviours of the base class Module (which does nothing at all)
 
 Module::Module()
 	: ModuleDLLManager(NULL)
@@ -133,18 +133,19 @@ void		Module::OnPostTopicChange(User*, Channel*, const std::string&) { DetachEve
 void		Module::OnDecodeMetaData(Extensible*, const std::string&, const std::string&) { DetachEvent(I_OnDecodeMetaData); }
 void		Module::OnChangeHost(User*, const std::string&) { DetachEvent(I_OnChangeHost); }
 void		Module::OnChangeRealHost(User*, const std::string&) { DetachEvent(I_OnChangeRealHost); }
+void		Module::OnPostChangeRealHost(User*) { DetachEvent(I_OnPostChangeRealHost); }
 void		Module::OnChangeRealName(User*, const std::string&) { DetachEvent(I_OnChangeRealName); }
 void		Module::OnChangeIdent(User*, const std::string&) { DetachEvent(I_OnChangeIdent); }
 void		Module::OnAddLine(User*, XLine*) { DetachEvent(I_OnAddLine); }
 void		Module::OnDelLine(User*, XLine*) { DetachEvent(I_OnDelLine); }
 void		Module::OnExpireLine(XLine*) { DetachEvent(I_OnExpireLine); }
-void 		Module::OnCleanup(ExtensionItem::ExtensibleType, Extensible*) { }
+void		Module::OnCleanup(ExtensionItem::ExtensibleType, Extensible*) { }
 ModResult	Module::OnChannelPreDelete(Channel*) { DetachEvent(I_OnChannelPreDelete); return MOD_RES_PASSTHRU; }
 void		Module::OnChannelDelete(Channel*) { DetachEvent(I_OnChannelDelete); }
 void		Module::OnBuildNeighborList(User*, IncludeChanList&, std::map<User*,bool>&) { DetachEvent(I_OnBuildNeighborList); }
 void		Module::OnGarbageCollect() { DetachEvent(I_OnGarbageCollect); }
 ModResult	Module::OnSetConnectClass(LocalUser* user, ConnectClass* myclass) { DetachEvent(I_OnSetConnectClass); return MOD_RES_PASSTHRU; }
-void 		Module::OnUserMessage(User*, const MessageTarget&, const MessageDetails&) { DetachEvent(I_OnUserMessage); }
+void		Module::OnUserMessage(User*, const MessageTarget&, const MessageDetails&) { DetachEvent(I_OnUserMessage); }
 ModResult	Module::OnNumeric(User*, const Numeric::Numeric&) { DetachEvent(I_OnNumeric); return MOD_RES_PASSTHRU; }
 ModResult   Module::OnAcceptConnection(int, ListenSocket*, irc::sockets::sockaddrs*, irc::sockets::sockaddrs*) { DetachEvent(I_OnAcceptConnection); return MOD_RES_PASSTHRU; }
 void		Module::OnSetUserIP(LocalUser*) { DetachEvent(I_OnSetUserIP); }
@@ -167,6 +168,26 @@ void ServiceProvider::DisableAutoRegister()
 		stdalgo::erase(*ServerInstance->Modules->NewServices, this);
 }
 
+const char* ServiceProvider::GetTypeString() const
+{
+	switch (service)
+	{
+		case SERVICE_COMMAND:
+			return "command";
+		case SERVICE_MODE:
+			return "mode";
+		case SERVICE_METADATA:
+			return "metadata";
+		case SERVICE_IOHOOK:
+			return "iohook";
+		case SERVICE_DATA:
+			return "data service";
+		case SERVICE_CUSTOM:
+			return "module service";
+	}
+	return "unknown service";
+}
+
 ModuleManager::ModuleManager()
 {
 }
@@ -297,17 +318,17 @@ swap_now:
 		if (prioritizationState == PRIO_STATE_LAST)
 			prioritizationState = PRIO_STATE_AGAIN;
 		/* Suggestion from Phoenix, "shuffle" the modules to better retain call order */
-		int incrmnt = 1;
+		int increment = 1;
 
 		if (my_pos > swap_pos)
-			incrmnt = -1;
+			increment = -1;
 
-		for (unsigned int j = my_pos; j != swap_pos; j += incrmnt)
+		for (unsigned int j = my_pos; j != swap_pos; j += increment)
 		{
-			if ((j + incrmnt > EventHandlers[i].size() - 1) || ((incrmnt == -1) && (j == 0)))
+			if ((j + increment > EventHandlers[i].size() - 1) || ((increment == -1) && (j == 0)))
 				continue;
 
-			std::swap(EventHandlers[i][j], EventHandlers[i][j+incrmnt]);
+			std::swap(EventHandlers[i][j], EventHandlers[i][j+increment]);
 		}
 	}
 
@@ -405,11 +426,14 @@ void ModuleManager::DoSafeUnload(Module* mod)
 		user->doUnhookExtensions(items);
 	}
 
-	for(std::multimap<std::string, ServiceProvider*>::iterator i = DataProviders.begin(); i != DataProviders.end(); )
+	for (DataProviderMap::iterator i = DataProviders.begin(); i != DataProviders.end(); )
 	{
-		std::multimap<std::string, ServiceProvider*>::iterator curr = i++;
+		DataProviderMap::iterator curr = i++;
 		if (curr->second->creator == mod)
+		{
 			DataProviders.erase(curr);
+			FOREACH_MOD(OnServiceDel, (*curr->second));
+		}
 	}
 
 	dynamic_reference_base::reset_all();
@@ -419,7 +443,7 @@ void ModuleManager::DoSafeUnload(Module* mod)
 	Modules.erase(modfind);
 	ServerInstance->GlobalCulls.AddItem(mod);
 
-	ServerInstance->Logs->Log("MODULE", LOG_DEFAULT, "Module %s unloaded",mod->ModuleSourceFile.c_str());
+	ServerInstance->Logs->Log("MODULE", LOG_DEFAULT, "The %s module was unloaded", mod->ModuleSourceFile.c_str());
 	ServerInstance->ISupport.Build();
 }
 
@@ -427,7 +451,7 @@ void ModuleManager::UnloadAll()
 {
 	/* We do this more than once, so that any service providers get a
 	 * chance to be unhooked by the modules using them, but then get
-	 * a chance to be removed themsleves.
+	 * a chance to be removed themselves.
 	 *
 	 * Note: this deliberately does NOT delete the DLLManager objects
 	 */
@@ -562,6 +586,8 @@ void ModuleManager::AddServices(const ServiceList& list)
 
 void ModuleManager::AddService(ServiceProvider& item)
 {
+	ServerInstance->Logs->Log("SERVICE", LOG_DEBUG, "Adding %s %s provided by %s", item.name.c_str(),
+		item.GetTypeString(), item.creator ? item.creator->ModuleSourceFile.c_str() : "the core");
 	switch (item.service)
 	{
 		case SERVICE_DATA:
@@ -574,9 +600,10 @@ void ModuleManager::AddService(ServiceProvider& item)
 			std::string::size_type slash = item.name.find('/');
 			if (slash != std::string::npos)
 			{
+				// Also register foo/bar as foo.
 				DataProviders.insert(std::make_pair(item.name.substr(0, slash), &item));
-				DataProviders.insert(std::make_pair(item.name.substr(slash + 1), &item));
 			}
+
 			dynamic_reference_base::reset_all();
 			break;
 		}
@@ -589,6 +616,8 @@ void ModuleManager::AddService(ServiceProvider& item)
 
 void ModuleManager::DelService(ServiceProvider& item)
 {
+	ServerInstance->Logs->Log("SERVICE", LOG_DEBUG, "Deleting %s %s provided by %s", item.name.c_str(),
+		item.GetTypeString(), item.creator ? item.creator->ModuleSourceFile.c_str() : "the core");
 	switch (item.service)
 	{
 		case SERVICE_MODE:
@@ -599,7 +628,7 @@ void ModuleManager::DelService(ServiceProvider& item)
 		case SERVICE_IOHOOK:
 		{
 			DelReferent(&item);
-			return;
+			break;
 		}
 		default:
 			throw ModuleException("Cannot delete unknown service type");
@@ -615,7 +644,7 @@ ServiceProvider* ModuleManager::FindService(ServiceType type, const std::string&
 		case SERVICE_DATA:
 		case SERVICE_IOHOOK:
 		{
-			std::multimap<std::string, ServiceProvider*>::iterator i = DataProviders.find(name);
+			DataProviderMap::iterator i = DataProviders.find(name);
 			if (i != DataProviders.end() && i->second->service == type)
 				return i->second;
 			return NULL;
@@ -669,7 +698,7 @@ void dynamic_reference_base::resolve()
 {
 	// Because find() may return any element with a matching key in case count(key) > 1 use lower_bound()
 	// to ensure a dynref with the same name as another one resolves to the same object
-	std::multimap<std::string, ServiceProvider*>::iterator i = ServerInstance->Modules.DataProviders.lower_bound(name);
+	ModuleManager::DataProviderMap::iterator i = ServerInstance->Modules.DataProviders.lower_bound(name);
 	if ((i != ServerInstance->Modules.DataProviders.end()) && (i->first == this->name))
 	{
 		ServiceProvider* newvalue = i->second;
@@ -702,7 +731,7 @@ void ModuleManager::AddReferent(const std::string& name, ServiceProvider* servic
 
 void ModuleManager::DelReferent(ServiceProvider* service)
 {
-	for (std::multimap<std::string, ServiceProvider*>::iterator i = DataProviders.begin(); i != DataProviders.end(); )
+	for (DataProviderMap::iterator i = DataProviders.begin(); i != DataProviders.end(); )
 	{
 		ServiceProvider* curr = i->second;
 		if (curr == service)
