@@ -3,7 +3,7 @@
  *
  *   Copyright (C) 2020 Matt Schatz <genius3000@g3k.solutions>
  *   Copyright (C) 2019 linuxdaemon <linuxdaemon.irc@gmail.com>
- *   Copyright (C) 2013-2014, 2016-2020 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2013-2014, 2016-2021 Sadie Powell <sadie@witchery.services>
  *   Copyright (C) 2013 Daniel Vassdal <shutter@canternet.org>
  *   Copyright (C) 2012-2017 Attila Molnar <attilamolnar@hush.com>
  *   Copyright (C) 2012-2013, 2016 Adam <Adam@anope.org>
@@ -40,7 +40,7 @@
 /// $PackageInfo: require_system("centos") gnutls-devel pkgconfig
 /// $PackageInfo: require_system("darwin") gnutls pkg-config
 /// $PackageInfo: require_system("debian") gnutls-bin libgnutls28-dev pkg-config
-/// $PackageInfo: require_system("ubuntu") gnutls-bin libgnutls-dev pkg-config
+/// $PackageInfo: require_system("ubuntu") gnutls-bin libgnutls28-dev pkg-config
 
 #include "inspircd.h"
 #include "modules/ssl.h"
@@ -68,8 +68,12 @@
 # pragma GCC diagnostic pop
 #endif
 
-// Fix warnings about using std::auto_ptr on C++11 or newer.
-#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
+// C++98 compilers can't use shared_ptr and C++17 compilers can't use auto_ptr.
+#if defined _LIBCPP_VERSION || defined _WIN32 || __cplusplus >= 201103L
+# define SMART_PTR std::shared_ptr
+#else
+# define SMART_PTR std::auto_ptr
+#endif
 
 #ifndef GNUTLS_VERSION_NUMBER
 #define GNUTLS_VERSION_NUMBER LIBGNUTLS_VERSION_NUMBER
@@ -99,8 +103,6 @@
 #define GNUTLS_NEW_PRIO_API
 #endif
 
-enum issl_status { ISSL_NONE, ISSL_HANDSHAKING, ISSL_HANDSHAKEN };
-
 #if INSPIRCD_GNUTLS_HAS_VERSION(2, 12, 0)
 #define INSPIRCD_GNUTLS_HAS_VECTOR_PUSH
 #define GNUTLS_NEW_CERT_CALLBACK_API
@@ -229,9 +231,9 @@ namespace GnuTLS
 
 	 public:
 		/** Import */
-		static std::auto_ptr<DHParams> Import(const std::string& dhstr)
+		static SMART_PTR<DHParams> Import(const std::string& dhstr)
 		{
-			std::auto_ptr<DHParams> dh(new DHParams);
+			SMART_PTR<DHParams> dh(new DHParams);
 			int ret = gnutls_dh_params_import_pkcs3(dh->dh_params, Datum(dhstr).get(), GNUTLS_X509_FMT_PEM);
 			ThrowOnError(ret, "Unable to import DH params");
 			return dh;
@@ -443,7 +445,7 @@ namespace GnuTLS
 	{
 		/** DH parameters associated with these credentials
 		 */
-		std::auto_ptr<DHParams> dh;
+		SMART_PTR<DHParams> dh;
 
 	 protected:
 		gnutls_certificate_credentials_t cred;
@@ -468,7 +470,7 @@ namespace GnuTLS
 
 		/** Set the given DH parameters to be used with these credentials
 		 */
-		void SetDH(std::auto_ptr<DHParams>& DH)
+		void SetDH(SMART_PTR<DHParams>& DH)
 		{
 			dh = DH;
 			gnutls_certificate_set_dh_params(cred, dh->get());
@@ -487,11 +489,11 @@ namespace GnuTLS
 
 		/** Trusted CA, may be NULL
 		 */
-		std::auto_ptr<X509CertList> trustedca;
+		SMART_PTR<X509CertList> trustedca;
 
 		/** Certificate revocation list, may be NULL
 		 */
-		std::auto_ptr<X509CRL> crl;
+		SMART_PTR<X509CRL> crl;
 
 		static int cert_callback(gnutls_session_t session, const gnutls_datum_t* req_ca_rdn, int nreqs, const gnutls_pk_algorithm_t* sign_algos, int sign_algos_length, cert_cb_last_param_type* st);
 
@@ -514,7 +516,7 @@ namespace GnuTLS
 		/** Sets the trusted CA and the certificate revocation list
 		 * to use when verifying certificates
 		 */
-		void SetCA(std::auto_ptr<X509CertList>& certlist, std::auto_ptr<X509CRL>& CRL)
+		void SetCA(SMART_PTR<X509CertList>& certlist, SMART_PTR<X509CRL>& CRL)
 		{
 			// Do nothing if certlist is NULL
 			if (certlist.get())
@@ -648,12 +650,12 @@ namespace GnuTLS
 		{
 			std::string name;
 
-			std::auto_ptr<X509CertList> ca;
-			std::auto_ptr<X509CRL> crl;
+			SMART_PTR<X509CertList> ca;
+			SMART_PTR<X509CRL> crl;
 
 			std::string certstr;
 			std::string keystr;
-			std::auto_ptr<DHParams> dh;
+			SMART_PTR<DHParams> dh;
 
 			std::string priostr;
 			unsigned int mindh;
@@ -728,7 +730,6 @@ class GnuTLSIOHook : public SSLIOHook
 {
  private:
 	gnutls_session_t sess;
-	issl_status status;
 #ifdef INSPIRCD_GNUTLS_HAS_CORK
 	size_t gbuffersize;
 #endif
@@ -742,7 +743,7 @@ class GnuTLSIOHook : public SSLIOHook
 		}
 		sess = NULL;
 		certificate = NULL;
-		status = ISSL_NONE;
+		status = STATUS_NONE;
 	}
 
 	// Returns 1 if handshake succeeded, 0 if it is still in progress, -1 if it failed
@@ -755,7 +756,7 @@ class GnuTLSIOHook : public SSLIOHook
 			if(ret == GNUTLS_E_AGAIN || ret == GNUTLS_E_INTERRUPTED)
 			{
 				// Handshake needs resuming later, read() or write() would have blocked.
-				this->status = ISSL_HANDSHAKING;
+				this->status = STATUS_HANDSHAKING;
 
 				if (gnutls_record_get_direction(this->sess) == 0)
 				{
@@ -779,8 +780,8 @@ class GnuTLSIOHook : public SSLIOHook
 		}
 		else
 		{
-			// Change the seesion state
-			this->status = ISSL_HANDSHAKEN;
+			// Change the session state
+			this->status = STATUS_OPEN;
 
 			VerifyCertificate();
 
@@ -793,26 +794,14 @@ class GnuTLSIOHook : public SSLIOHook
 
 	void VerifyCertificate()
 	{
-		unsigned int certstatus;
-		const gnutls_datum_t* cert_list;
-		int ret;
-		unsigned int cert_list_size;
-		gnutls_x509_crt_t cert;
-		char str[512];
-		unsigned char digest[512];
-		size_t digest_size = sizeof(digest);
-		size_t name_size = sizeof(str);
 		ssl_cert* certinfo = new ssl_cert;
 		this->certificate = certinfo;
 
-		/* This verification function uses the trusted CAs in the credentials
-		 * structure. So you must have installed one or more CA certificates.
-		 */
-		ret = gnutls_certificate_verify_peers2(this->sess, &certstatus);
-
+		unsigned int certstatus;
+		int ret = gnutls_certificate_verify_peers2(this->sess, &certstatus);
 		if (ret < 0)
 		{
-			certinfo->error = std::string(gnutls_strerror(ret));
+			certinfo->error = gnutls_strerror(ret);
 			return;
 		}
 
@@ -821,16 +810,13 @@ class GnuTLSIOHook : public SSLIOHook
 		certinfo->revoked = (certstatus & GNUTLS_CERT_REVOKED);
 		certinfo->trusted = !(certstatus & GNUTLS_CERT_SIGNER_NOT_CA);
 
-		/* Up to here the process is the same for X.509 certificates and
-		 * OpenPGP keys. From now on X.509 certificates are assumed. This can
-		 * be easily extended to work with openpgp keys as well.
-		 */
 		if (gnutls_certificate_type_get(this->sess) != GNUTLS_CRT_X509)
 		{
 			certinfo->error = "No X509 keys sent";
 			return;
 		}
 
+		gnutls_x509_crt_t cert;
 		ret = gnutls_x509_crt_init(&cert);
 		if (ret < 0)
 		{
@@ -838,18 +824,17 @@ class GnuTLSIOHook : public SSLIOHook
 			return;
 		}
 
-		cert_list_size = 0;
-		cert_list = gnutls_certificate_get_peers(this->sess, &cert_list_size);
+		char buffer[512];
+		size_t buffer_size = sizeof(buffer);
+
+		unsigned int cert_list_size = 0;
+		const gnutls_datum_t* cert_list = gnutls_certificate_get_peers(this->sess, &cert_list_size);
 		if (cert_list == NULL)
 		{
 			certinfo->error = "No certificate was found";
 			goto info_done_dealloc;
 		}
 
-		/* This is not a real world example, since we only check the first
-		 * certificate in the given chain.
-		 */
-
 		ret = gnutls_x509_crt_import(cert, &cert_list[0], GNUTLS_X509_FMT_DER);
 		if (ret < 0)
 		{
@@ -857,31 +842,21 @@ class GnuTLSIOHook : public SSLIOHook
 			goto info_done_dealloc;
 		}
 
-		if (gnutls_x509_crt_get_dn(cert, str, &name_size) == 0)
-		{
-			std::string& dn = certinfo->dn;
-			dn = str;
-			// Make sure there are no chars in the string that we consider invalid
-			if (dn.find_first_of("\r\n") != std::string::npos)
-				dn.clear();
-		}
+		if (gnutls_x509_crt_get_dn(cert, buffer, &buffer_size) == 0)
+			ProcessDNString(buffer, buffer_size, certinfo->dn);
 
-		name_size = sizeof(str);
-		if (gnutls_x509_crt_get_issuer_dn(cert, str, &name_size) == 0)
-		{
-			std::string& issuer = certinfo->issuer;
-			issuer = str;
-			if (issuer.find_first_of("\r\n") != std::string::npos)
-				issuer.clear();
-		}
+		buffer_size = sizeof(buffer);
+		if (gnutls_x509_crt_get_issuer_dn(cert, buffer, &buffer_size) == 0)
+			ProcessDNString(buffer, buffer_size, certinfo->issuer);
 
-		if ((ret = gnutls_x509_crt_get_fingerprint(cert, GetProfile().GetHash(), digest, &digest_size)) < 0)
+		buffer_size = sizeof(buffer);
+		if ((ret = gnutls_x509_crt_get_fingerprint(cert, GetProfile().GetHash(), buffer, &buffer_size)) < 0)
 		{
 			certinfo->error = gnutls_strerror(ret);
 		}
 		else
 		{
-			certinfo->fingerprint = BinToHex(digest, digest_size);
+			certinfo->fingerprint = BinToHex(buffer, buffer_size);
 		}
 
 		/* Beware here we do not check for errors.
@@ -895,12 +870,19 @@ info_done_dealloc:
 		gnutls_x509_crt_deinit(cert);
 	}
 
+	static void ProcessDNString(const char* buffer, size_t buffer_size, std::string& out)
+	{
+		out.assign(buffer, buffer_size);
+		for (size_t pos = 0; ((pos = out.find_first_of("\r\n", pos)) != std::string::npos); )
+			out[pos] = ' ';
+	}
+
 	// Returns 1 if application I/O should proceed, 0 if it must wait for the underlying protocol to progress, -1 on fatal error
 	int PrepareIO(StreamSocket* sock)
 	{
-		if (status == ISSL_HANDSHAKEN)
+		if (status == STATUS_OPEN)
 			return 1;
-		else if (status == ISSL_HANDSHAKING)
+		else if (status == STATUS_HANDSHAKING)
 		{
 			// The handshake isn't finished, try to finish it
 			return Handshake(sock);
@@ -1066,7 +1048,6 @@ info_done_dealloc:
 	GnuTLSIOHook(IOHookProvider* hookprov, StreamSocket* sock, inspircd_gnutls_session_init_flags_t flags)
 		: SSLIOHook(hookprov)
 		, sess(NULL)
-		, status(ISSL_NONE)
 #ifdef INSPIRCD_GNUTLS_HAS_CORK
 		, gbuffersize(0)
 #endif
@@ -1097,7 +1078,7 @@ info_done_dealloc:
 		if (prepret <= 0)
 			return prepret;
 
-		// If we resumed the handshake then this->status will be ISSL_HANDSHAKEN.
+		// If we resumed the handshake then this->status will be STATUS_OPEN.
 		{
 			GnuTLS::DataReader reader(sess);
 			int ret = reader.ret();
@@ -1193,7 +1174,7 @@ info_done_dealloc:
 
 	void GetCiphersuite(std::string& out) const CXX11_OVERRIDE
 	{
-		if (!IsHandshakeDone())
+		if (!IsHookReady())
 			return;
 		out.append(UnknownIfNULL(gnutls_protocol_get_name(gnutls_protocol_get_version(sess)))).push_back('-');
 		out.append(UnknownIfNULL(gnutls_kx_get_name(gnutls_kx_get(sess)))).push_back('-');
@@ -1221,7 +1202,6 @@ info_done_dealloc:
 	}
 
 	GnuTLS::Profile& GetProfile();
-	bool IsHandshakeDone() const { return (status == ISSL_HANDSHAKEN); }
 };
 
 int GnuTLS::X509Credentials::cert_callback(gnutls_session_t sess, const gnutls_datum_t* req_ca_rdn, int nreqs, const gnutls_pk_algorithm_t* sign_algos, int sign_algos_length, cert_cb_last_param_type* st)
@@ -1243,13 +1223,13 @@ int GnuTLS::X509Credentials::cert_callback(gnutls_session_t sess, const gnutls_d
 	return 0;
 }
 
-class GnuTLSIOHookProvider : public IOHookProvider
+class GnuTLSIOHookProvider : public SSLIOHookProvider
 {
 	GnuTLS::Profile profile;
 
  public:
- 	GnuTLSIOHookProvider(Module* mod, GnuTLS::Profile::Config& config)
-		: IOHookProvider(mod, "ssl/" + config.name, IOHookProvider::IOH_SSL)
+	GnuTLSIOHookProvider(Module* mod, GnuTLS::Profile::Config& config)
+		: SSLIOHookProvider(mod, config.name)
 		, profile(config)
 	{
 		ServerInstance->Modules->AddService(*this);
@@ -1314,7 +1294,7 @@ class ModuleSSLGnuTLS : public Module
 		}
 		else
 		{
-			ServerInstance->Logs->Log(MODNAME, LOG_DEFAULT, "You have defined an <sslprofile> tag; you should use this in place of \"gnutls\" when configuring TLS (SSL) connections in <bind:ssl> or <link:ssl>");
+			ServerInstance->Logs->Log(MODNAME, LOG_DEFAULT, "You have defined an <sslprofile> tag; you should use this in place of \"gnutls\" when configuring TLS (SSL) connections in <bind:sslprofile> or <link:sslprofile>");
 			for (ConfigIter i = tags.first; i != tags.second; ++i)
 			{
 				ConfigTag* tag = i->second;
@@ -1369,10 +1349,16 @@ class ModuleSSLGnuTLS : public Module
 	void init() CXX11_OVERRIDE
 	{
 		ServerInstance->Logs->Log(MODNAME, LOG_DEFAULT, "GnuTLS lib version %s module was compiled for " GNUTLS_VERSION, gnutls_check_version(NULL));
-		ReadProfiles();
 		ServerInstance->GenRandom = RandGen::Call;
 	}
 
+	void ReadConfig(ConfigStatus& status) CXX11_OVERRIDE
+	{
+		ConfigTag* tag = ServerInstance->Config->ConfValue("gnutls");
+		if (status.initial || tag->getBool("onrehash"))
+			ReadProfiles();
+	}
+
 	void OnModuleRehash(User* user, const std::string &param) CXX11_OVERRIDE
 	{
 		if (!irc::equals(param, "tls") && !irc::equals(param, "ssl"))
@@ -1381,11 +1367,11 @@ class ModuleSSLGnuTLS : public Module
 		try
 		{
 			ReadProfiles();
-			ServerInstance->SNO->WriteToSnoMask('a', "TLS (SSL) module GnuTLS rehashed.");
+			ServerInstance->SNO->WriteToSnoMask('a', "GnuTLS TLS (SSL) profiles have been reloaded.");
 		}
 		catch (ModuleException& ex)
 		{
-			ServerInstance->Logs->Log(MODNAME, LOG_DEFAULT, ex.GetReason() + " Not applying settings.");
+			ServerInstance->SNO->WriteToSnoMask('a', "Failed to reload the GnuTLS TLS (SSL) profiles. " + ex.GetReason());
 		}
 	}
 
@@ -1417,7 +1403,7 @@ class ModuleSSLGnuTLS : public Module
 	ModResult OnCheckReady(LocalUser* user) CXX11_OVERRIDE
 	{
 		const GnuTLSIOHook* const iohook = static_cast<GnuTLSIOHook*>(user->eh.GetModHook(this));
-		if ((iohook) && (!iohook->IsHandshakeDone()))
+		if ((iohook) && (!iohook->IsHookReady()))
 			return MOD_RES_DENY;
 		return MOD_RES_PASSTHRU;
 	}
