@@ -2,7 +2,7 @@
  * InspIRCd -- Internet Relay Chat Daemon
  *
  *   Copyright (C) 2020 Matt Schatz <genius3000@g3k.solutions>
- *   Copyright (C) 2016-2020 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2016-2021 Sadie Powell <sadie@witchery.services>
  *   Copyright (C) 2016-2017 Attila Molnar <attilamolnar@hush.com>
  *
  * This file is part of InspIRCd.  InspIRCd is free software: you can
@@ -40,6 +40,10 @@
 # endif
 #endif
 
+// Temporary fix for mbedTLS v3 not allowing access to grp_id without any
+// replacement API.
+#define MBEDTLS_ALLOW_PRIVATE_ACCESS
+
 #include <mbedtls/ctr_drbg.h>
 #include <mbedtls/dhm.h>
 #include <mbedtls/ecp.h>
@@ -137,7 +141,13 @@ namespace mbedTLS
 		/** Import */
 		X509Key(const std::string& keystr)
 		{
-			int ret = mbedtls_pk_parse_key(get(), reinterpret_cast<const unsigned char*>(keystr.c_str()), keystr.size()+1, NULL, 0);
+#if MBEDTLS_VERSION_MAJOR >= 3
+			int ret = mbedtls_pk_parse_key(get(), reinterpret_cast<const unsigned char*>(keystr.c_str()),
+				keystr.size() + 1, NULL, 0, mbedtls_ctr_drbg_random, 0);
+#else
+			int ret = mbedtls_pk_parse_key(get(), reinterpret_cast<const unsigned char*>(keystr.c_str()),
+				keystr.size() + 1, NULL, 0);
+#endif
 			ThrowOnError(ret, "Unable to import private key");
 		}
 	};
@@ -238,7 +248,13 @@ namespace mbedTLS
 			bool found = false;
 			for (mbedtls_x509_crt* cert = certs.get(); cert; cert = cert->next)
 			{
+
+#if MBEDTLS_VERSION_MAJOR >= 3
+				if (mbedtls_pk_check_pair(&cert->pk, key.get(), mbedtls_ctr_drbg_random, 0) == 0)
+#else
 				if (mbedtls_pk_check_pair(&cert->pk, key.get()) == 0)
+
+#endif
 				{
 					found = true;
 					break;
@@ -519,25 +535,18 @@ namespace mbedTLS
 
 class mbedTLSIOHook : public SSLIOHook
 {
-	enum Status
-	{
-		ISSL_NONE,
-		ISSL_HANDSHAKING,
-		ISSL_HANDSHAKEN
-	};
-
+ private:
 	mbedtls_ssl_context sess;
-	Status status;
 
 	void CloseSession()
 	{
-		if (status == ISSL_NONE)
+		if (status == STATUS_NONE)
 			return;
 
 		mbedtls_ssl_close_notify(&sess);
 		mbedtls_ssl_free(&sess);
 		certificate = NULL;
-		status = ISSL_NONE;
+		status = STATUS_NONE;
 	}
 
 	// Returns 1 if handshake succeeded, 0 if it is still in progress, -1 if it failed
@@ -546,8 +555,8 @@ class mbedTLSIOHook : public SSLIOHook
 		int ret = mbedtls_ssl_handshake(&sess);
 		if (ret == 0)
 		{
-			// Change the seesion state
-			this->status = ISSL_HANDSHAKEN;
+			// Change the session state
+			this->status = STATUS_OPEN;
 
 			VerifyCertificate();
 
@@ -557,7 +566,7 @@ class mbedTLSIOHook : public SSLIOHook
 			return 1;
 		}
 
-		this->status = ISSL_HANDSHAKING;
+		this->status = STATUS_HANDSHAKING;
 		if (ret == MBEDTLS_ERR_SSL_WANT_READ)
 		{
 			SocketEngine::ChangeEventMask(sock, FD_WANT_POLL_READ | FD_WANT_NO_WRITE);
@@ -577,9 +586,9 @@ class mbedTLSIOHook : public SSLIOHook
 	// Returns 1 if application I/O should proceed, 0 if it must wait for the underlying protocol to progress, -1 on fatal error
 	int PrepareIO(StreamSocket* sock)
 	{
-		if (status == ISSL_HANDSHAKEN)
+		if (status == STATUS_OPEN)
 			return 1;
-		else if (status == ISSL_HANDSHAKING)
+		else if (status == STATUS_HANDSHAKING)
 		{
 			// The handshake isn't finished, try to finish it
 			return Handshake(sock);
@@ -640,6 +649,8 @@ class mbedTLSIOHook : public SSLIOHook
 			return;
 
 		out.assign(buf, ret);
+		for (size_t pos = 0; ((pos = out.find_first_of("\r\n", pos)) != std::string::npos); )
+			out[pos] = ' ';
 	}
 
 	static int Pull(void* userptr, unsigned char* buffer, size_t size)
@@ -677,7 +688,6 @@ class mbedTLSIOHook : public SSLIOHook
  public:
 	mbedTLSIOHook(IOHookProvider* hookprov, StreamSocket* sock, bool isserver)
 		: SSLIOHook(hookprov)
-		, status(ISSL_NONE)
 	{
 		mbedtls_ssl_init(&sess);
 		if (isserver)
@@ -703,7 +713,7 @@ class mbedTLSIOHook : public SSLIOHook
 		if (prepret <= 0)
 			return prepret;
 
-		// If we resumed the handshake then this->status will be ISSL_HANDSHAKEN.
+		// If we resumed the handshake then this->status will be STATUS_OPEN.
 		char* const readbuf = ServerInstance->GetReadBuffer();
 		const size_t readbufsize = ServerInstance->Config->NetBufferSize;
 		int ret = mbedtls_ssl_read(&sess, reinterpret_cast<unsigned char*>(readbuf), readbufsize);
@@ -794,7 +804,7 @@ class mbedTLSIOHook : public SSLIOHook
 
 	void GetCiphersuite(std::string& out) const CXX11_OVERRIDE
 	{
-		if (!IsHandshakeDone())
+		if (!IsHookReady())
 			return;
 		out.append(mbedtls_ssl_get_version(&sess)).push_back('-');
 
@@ -814,16 +824,15 @@ class mbedTLSIOHook : public SSLIOHook
 	}
 
 	mbedTLS::Profile& GetProfile();
-	bool IsHandshakeDone() const { return (status == ISSL_HANDSHAKEN); }
 };
 
-class mbedTLSIOHookProvider : public IOHookProvider
+class mbedTLSIOHookProvider : public SSLIOHookProvider
 {
 	mbedTLS::Profile profile;
 
  public:
- 	mbedTLSIOHookProvider(Module* mod, mbedTLS::Profile::Config& config)
-		: IOHookProvider(mod, "ssl/" + config.name, IOHookProvider::IOH_SSL)
+	mbedTLSIOHookProvider(Module* mod, mbedTLS::Profile::Config& config)
+		: SSLIOHookProvider(mod, config.name)
 		, profile(config)
 	{
 		ServerInstance->Modules->AddService(*this);
@@ -888,7 +897,7 @@ class ModuleSSLmbedTLS : public Module
 		}
 		else
 		{
-			ServerInstance->Logs->Log(MODNAME, LOG_DEFAULT, "You have defined an <sslprofile> tag; you should use this in place of \"mbedtls\" when configuring TLS (SSL) connections in <bind:ssl> or <link:ssl>");
+			ServerInstance->Logs->Log(MODNAME, LOG_DEFAULT, "You have defined an <sslprofile> tag; you should use this in place of \"mbedtls\" when configuring TLS (SSL) connections in <bind:sslprofile> or <link:sslprofile>");
 			for (ConfigIter i = tags.first; i != tags.second; ++i)
 			{
 				ConfigTag* tag = i->second;
@@ -940,7 +949,13 @@ class ModuleSSLmbedTLS : public Module
 
 		if (!ctr_drbg.Seed(entropy))
 			throw ModuleException("CTR DRBG seed failed");
-		ReadProfiles();
+	}
+
+	void ReadConfig(ConfigStatus& status) CXX11_OVERRIDE
+	{
+		ConfigTag* tag = ServerInstance->Config->ConfValue("mbedtls");
+		if (status.initial || tag->getBool("onrehash"))
+			ReadProfiles();
 	}
 
 	void OnModuleRehash(User* user, const std::string &param) CXX11_OVERRIDE
@@ -951,11 +966,11 @@ class ModuleSSLmbedTLS : public Module
 		try
 		{
 			ReadProfiles();
-			ServerInstance->SNO->WriteToSnoMask('a', "TLS (SSL) module mbedTLS rehashed.");
+			ServerInstance->SNO->WriteToSnoMask('a', "mbedTLS TLS (SSL) profiles have been reloaded.");
 		}
 		catch (ModuleException& ex)
 		{
-			ServerInstance->Logs->Log(MODNAME, LOG_DEFAULT, ex.GetReason() + " Not applying settings.");
+			ServerInstance->SNO->WriteToSnoMask('a', "Failed to reload the mbedTLS TLS (SSL) profiles. " + ex.GetReason());
 		}
 	}
 
@@ -976,7 +991,7 @@ class ModuleSSLmbedTLS : public Module
 	ModResult OnCheckReady(LocalUser* user) CXX11_OVERRIDE
 	{
 		const mbedTLSIOHook* const iohook = static_cast<mbedTLSIOHook*>(user->eh.GetModHook(this));
-		if ((iohook) && (!iohook->IsHandshakeDone()))
+		if ((iohook) && (!iohook->IsHookReady()))
 			return MOD_RES_DENY;
 		return MOD_RES_PASSTHRU;
 	}
