@@ -6,14 +6,15 @@
  *   Copyright (C) 2017 Wade Cline <wadecline@hotmail.com>
  *   Copyright (C) 2014, 2016 Adam <Adam@anope.org>
  *   Copyright (C) 2014 Julien Vehent <julien@linuxwall.info>
- *   Copyright (C) 2013-2014, 2016-2020 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2013-2014, 2016-2021 Sadie Powell <sadie@witchery.services>
  *   Copyright (C) 2012-2017 Attila Molnar <attilamolnar@hush.com>
  *   Copyright (C) 2012 Robby <robby@chatbelgie.be>
  *   Copyright (C) 2012 ChrisTX <xpipe@hotmail.de>
  *   Copyright (C) 2009-2010 Daniel De Graaf <danieldg@inspircd.org>
  *   Copyright (C) 2008 Robin Burchell <robin+git@viroteck.net>
- *   Copyright (C) 2007-2008, 2010 Craig Edwards <brain@inspircd.org>
  *   Copyright (C) 2007 Dennis Friis <peavey@inspircd.org>
+ *   Copyright (C) 2006-2008, 2010 Craig Edwards <brain@inspircd.org>
+ *   Copyright (C) 2006 Oliver Lupton <om@inspircd.org>
  *
  * This file is part of InspIRCd.  InspIRCd is free software: you can
  * redistribute it and/or modify it under the terms of the GNU General Public
@@ -28,7 +29,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-/// $CompilerFlags: find_compiler_flags("openssl")
+/// $CompilerFlags: find_compiler_flags("openssl" "")
 /// $LinkerFlags: find_linker_flags("openssl" "-lssl -lcrypto")
 
 /// $PackageInfo: require_system("arch") openssl pkgconf
@@ -55,7 +56,9 @@
 // to support. Support for it was removed in the master branch at the same time that
 // support for OpenSSL pre-1.1 was.
 #if defined __GNUC__ && defined LIBRESSL_VERSION_NUMBER
-# warning LibreSSL support will be discontinued in the future. Consider using the ssl_gnutls or ssl_mbedtls modules instead.
+# undef OPENSSL_VERSION_NUMBER
+# define OPENSSL_VERSION_NUMBER 0x10000000L
+# warning LibreSSL support will be removed in v4. Consider using the ssl_gnutls or ssl_mbedtls modules instead if you can not use OpenSSL.
 #endif
 
 // Fix warnings about the use of `long long` on C++03.
@@ -79,7 +82,7 @@
 #endif
 
 // Compatibility layer to allow OpenSSL 1.0 to use the 1.1 API.
-#if ((defined LIBRESSL_VERSION_NUMBER) || (OPENSSL_VERSION_NUMBER < 0x10100000L))
+#if OPENSSL_VERSION_NUMBER < 0x10100000L
 
 // BIO is opaque in OpenSSL 1.1 but the access API does not exist in 1.0.
 # define BIO_get_data(BIO) BIO->ptr
@@ -101,8 +104,6 @@
 # define INSPIRCD_OPENSSL_OPAQUE_BIO
 #endif
 
-enum issl_status { ISSL_NONE, ISSL_HANDSHAKING, ISSL_OPEN };
-
 static bool SelfSigned = false;
 static int exdataindex;
 
@@ -216,10 +217,20 @@ namespace OpenSSL
 
 		bool SetCiphers(const std::string& ciphers)
 		{
+			// TLSv1 to TLSv1.2 ciphers.
 			ERR_clear_error();
 			return SSL_CTX_set_cipher_list(ctx, ciphers.c_str());
 		}
 
+#if OPENSSL_VERSION_NUMBER >= 0x10101000L
+		bool SetCiphersuites(const std::string& ciphers)
+		{
+			// TLSv1.3+ ciphers.
+			ERR_clear_error();
+			return SSL_CTX_set_ciphersuites(ctx, ciphers.c_str());
+		}
+#endif
+
 		bool SetCerts(const std::string& filename)
 		{
 			ERR_clear_error();
@@ -325,7 +336,7 @@ namespace OpenSSL
 		/** OpenSSL makes us have two contexts, one for servers and one for clients
 		 */
 		Context ctx;
-		Context clictx;
+		Context clientctx;
 
 		/** Digest to use when generating fingerprints
 		 */
@@ -395,11 +406,11 @@ namespace OpenSSL
 			: name(profilename)
 			, dh(ServerInstance->Config->Paths.PrependConfig(tag->getString("dhfile", "dhparams.pem", 1)))
 			, ctx(SSL_CTX_new(SSLv23_server_method()))
-			, clictx(SSL_CTX_new(SSLv23_client_method()))
+			, clientctx(SSL_CTX_new(SSLv23_client_method()))
 			, allowrenego(tag->getBool("renegotiation")) // Disallow by default
 			, outrecsize(tag->getUInt("outrecsize", 2048, 512, 16384))
 		{
-			if ((!ctx.SetDH(dh)) || (!clictx.SetDH(dh)))
+			if ((!ctx.SetDH(dh)) || (!clientctx.SetDH(dh)))
 				throw Exception("Couldn't set DH parameters");
 
 			const std::string hash = tag->getString("hash", "md5", 1);
@@ -407,16 +418,30 @@ namespace OpenSSL
 			if (digest == NULL)
 				throw Exception("Unknown hash type " + hash);
 
-			std::string ciphers = tag->getString("ciphers");
+			const std::string ciphers = tag->getString("ciphers");
 			if (!ciphers.empty())
 			{
-				if ((!ctx.SetCiphers(ciphers)) || (!clictx.SetCiphers(ciphers)))
+				if ((!ctx.SetCiphers(ciphers)) || (!clientctx.SetCiphers(ciphers)))
 				{
 					ERR_print_errors_cb(error_callback, this);
 					throw Exception("Can't set cipher list to \"" + ciphers + "\" " + lasterr);
 				}
 			}
 
+			const std::string ciphersuites = tag->getString("ciphersuites");
+			if (!ciphersuites.empty())
+			{
+#if OPENSSL_VERSION_NUMBER >= 0x10101000L
+				if ((!ctx.SetCiphersuites(ciphersuites)) || (!clientctx.SetCiphersuites(ciphersuites)))
+				{
+					ERR_print_errors_cb(error_callback, this);
+					throw Exception("Can't set ciphersuite list to \"" + ciphersuites + "\" " + lasterr);
+				}
+#else
+				ServerInstance->Logs->Log(MODNAME, LOG_DEBUG, "You have configured <sslprofile:ciphersuites> but your version of OpenSSL does not support TLSv1.3+");
+#endif
+			}
+
 #ifndef OPENSSL_NO_ECDH
 			const std::string curvename = tag->getString("ecdhcurve", "prime256v1", 1);
 			if (!curvename.empty())
@@ -424,20 +449,20 @@ namespace OpenSSL
 #endif
 
 			SetContextOptions("server", tag, ctx);
-			SetContextOptions("client", tag, clictx);
+			SetContextOptions("client", tag, clientctx);
 
 			/* Load our keys and certificates
 			 * NOTE: OpenSSL's error logging API sucks, don't blame us for this clusterfuck.
 			 */
 			std::string filename = ServerInstance->Config->Paths.PrependConfig(tag->getString("certfile", "cert.pem", 1));
-			if ((!ctx.SetCerts(filename)) || (!clictx.SetCerts(filename)))
+			if ((!ctx.SetCerts(filename)) || (!clientctx.SetCerts(filename)))
 			{
 				ERR_print_errors_cb(error_callback, this);
 				throw Exception("Can't read certificate file: " + lasterr);
 			}
 
 			filename = ServerInstance->Config->Paths.PrependConfig(tag->getString("keyfile", "key.pem", 1));
-			if ((!ctx.SetPrivateKey(filename)) || (!clictx.SetPrivateKey(filename)))
+			if ((!ctx.SetPrivateKey(filename)) || (!clientctx.SetPrivateKey(filename)))
 			{
 				ERR_print_errors_cb(error_callback, this);
 				throw Exception("Can't read key file: " + lasterr);
@@ -445,7 +470,7 @@ namespace OpenSSL
 
 			// Load the CAs we trust
 			filename = ServerInstance->Config->Paths.PrependConfig(tag->getString("cafile", "ca.pem", 1));
-			if ((!ctx.SetCA(filename)) || (!clictx.SetCA(filename)))
+			if ((!ctx.SetCA(filename)) || (!clientctx.SetCA(filename)))
 			{
 				ERR_print_errors_cb(error_callback, this);
 				ServerInstance->Logs->Log(MODNAME, LOG_DEFAULT, "Can't read CA list from %s. This is only a problem if you want to verify client certificates, otherwise it's safe to ignore this message. Error: %s", filename.c_str(), lasterr.c_str());
@@ -457,14 +482,14 @@ namespace OpenSSL
 			const std::string crlmode = tag->getString("crlmode", "chain", 1);
 			ctx.SetCRL(crlfile, crlpath, crlmode);
 
-			clictx.SetVerifyCert();
+			clientctx.SetVerifyCert();
 			if (tag->getBool("requestclientcert", true))
 				ctx.SetVerifyCert();
 		}
 
 		const std::string& GetName() const { return name; }
 		SSL* CreateServerSession() { return ctx.CreateServerSession(); }
-		SSL* CreateClientSession() { return clictx.CreateClientSession(); }
+		SSL* CreateClientSession() { return clientctx.CreateClientSession(); }
 		const EVP_MD* GetDigest() { return digest; }
 		bool AllowRenegotiation() const { return allowrenego; }
 		unsigned int GetOutgoingRecordSize() const { return outrecsize; }
@@ -549,7 +574,6 @@ class OpenSSLIOHook : public SSLIOHook
 {
  private:
 	SSL* sess;
-	issl_status status;
 	bool data_to_write;
 
 	// Returns 1 if handshake succeeded, 0 if it is still in progress, -1 if it failed
@@ -564,13 +588,13 @@ class OpenSSLIOHook : public SSLIOHook
 			if (err == SSL_ERROR_WANT_READ)
 			{
 				SocketEngine::ChangeEventMask(user, FD_WANT_POLL_READ | FD_WANT_NO_WRITE);
-				this->status = ISSL_HANDSHAKING;
+				this->status = STATUS_HANDSHAKING;
 				return 0;
 			}
 			else if (err == SSL_ERROR_WANT_WRITE)
 			{
 				SocketEngine::ChangeEventMask(user, FD_WANT_NO_READ | FD_WANT_SINGLE_WRITE);
-				this->status = ISSL_HANDSHAKING;
+				this->status = STATUS_HANDSHAKING;
 				return 0;
 			}
 			else
@@ -584,7 +608,7 @@ class OpenSSLIOHook : public SSLIOHook
 			// Handshake complete.
 			VerifyCertificate();
 
-			status = ISSL_OPEN;
+			status = STATUS_OPEN;
 
 			SocketEngine::ChangeEventMask(user, FD_WANT_POLL_READ | FD_WANT_NO_WRITE | FD_ADD_TRIAL_WRITE);
 
@@ -606,7 +630,7 @@ class OpenSSLIOHook : public SSLIOHook
 		}
 		sess = NULL;
 		certificate = NULL;
-		status = ISSL_NONE;
+		status = STATUS_NONE;
 	}
 
 	void VerifyCertificate()
@@ -638,17 +662,8 @@ class OpenSSLIOHook : public SSLIOHook
 			certinfo->trusted = false;
 		}
 
-		char buf[512];
-		X509_NAME_oneline(X509_get_subject_name(cert), buf, sizeof(buf));
-		certinfo->dn = buf;
-		// Make sure there are no chars in the string that we consider invalid
-		if (certinfo->dn.find_first_of("\r\n") != std::string::npos)
-			certinfo->dn.clear();
-
-		X509_NAME_oneline(X509_get_issuer_name(cert), buf, sizeof(buf));
-		certinfo->issuer = buf;
-		if (certinfo->issuer.find_first_of("\r\n") != std::string::npos)
-			certinfo->issuer.clear();
+		GetDNString(X509_get_subject_name(cert), certinfo->dn);
+		GetDNString(X509_get_issuer_name(cert), certinfo->issuer);
 
 		if (!X509_digest(cert, GetProfile().GetDigest(), md, &n))
 		{
@@ -667,16 +682,26 @@ class OpenSSLIOHook : public SSLIOHook
 		X509_free(cert);
 	}
 
+	static void GetDNString(const X509_NAME* x509name, std::string& out)
+	{
+		char buf[512];
+		X509_NAME_oneline(x509name, buf, sizeof(buf));
+
+		out.assign(buf);
+		for (size_t pos = 0; ((pos = out.find_first_of("\r\n", pos)) != std::string::npos); )
+			out[pos] = ' ';
+	}
+
 	void SSLInfoCallback(int where, int rc)
 	{
-		if ((where & SSL_CB_HANDSHAKE_START) && (status == ISSL_OPEN))
+		if ((where & SSL_CB_HANDSHAKE_START) && (status == STATUS_OPEN))
 		{
 			if (GetProfile().AllowRenegotiation())
 				return;
 
 			// The other side is trying to renegotiate, kill the connection and change status
-			// to ISSL_NONE so CheckRenego() closes the session
-			status = ISSL_NONE;
+			// to STATUS_NONE so CheckRenego() closes the session
+			status = STATUS_NONE;
 			BIO* bio = SSL_get_rbio(sess);
 			EventHandler* eh = static_cast<StreamSocket*>(BIO_get_data(bio));
 			SocketEngine::Shutdown(eh, 2);
@@ -685,7 +710,7 @@ class OpenSSLIOHook : public SSLIOHook
 
 	bool CheckRenego(StreamSocket* sock)
 	{
-		if (status != ISSL_NONE)
+		if (status != STATUS_NONE)
 			return true;
 
 		ServerInstance->Logs->Log(MODNAME, LOG_DEBUG, "Session %p killed, attempted to renegotiate", (void*)sess);
@@ -697,9 +722,9 @@ class OpenSSLIOHook : public SSLIOHook
 	// Returns 1 if application I/O should proceed, 0 if it must wait for the underlying protocol to progress, -1 on fatal error
 	int PrepareIO(StreamSocket* sock)
 	{
-		if (status == ISSL_OPEN)
+		if (status == STATUS_OPEN)
 			return 1;
-		else if (status == ISSL_HANDSHAKING)
+		else if (status == STATUS_HANDSHAKING)
 		{
 			// The handshake isn't finished, try to finish it
 			return Handshake(sock);
@@ -716,7 +741,6 @@ class OpenSSLIOHook : public SSLIOHook
 	OpenSSLIOHook(IOHookProvider* hookprov, StreamSocket* sock, SSL* session)
 		: SSLIOHook(hookprov)
 		, sess(session)
-		, status(ISSL_NONE)
 		, data_to_write(false)
 	{
 		// Create BIO instance and store a pointer to the socket in it which will be used by the read and write functions
@@ -745,7 +769,7 @@ class OpenSSLIOHook : public SSLIOHook
 		if (prepret <= 0)
 			return prepret;
 
-		// If we resumed the handshake then this->status will be ISSL_OPEN
+		// If we resumed the handshake then this->status will be STATUS_OPEN
 		{
 			ERR_clear_error();
 			char* buffer = ServerInstance->GetReadBuffer();
@@ -863,7 +887,7 @@ class OpenSSLIOHook : public SSLIOHook
 
 	void GetCiphersuite(std::string& out) const CXX11_OVERRIDE
 	{
-		if (!IsHandshakeDone())
+		if (!IsHookReady())
 			return;
 		out.append(SSL_get_version(sess)).push_back('-');
 		out.append(SSL_get_cipher(sess));
@@ -879,7 +903,6 @@ class OpenSSLIOHook : public SSLIOHook
 		return true;
 	}
 
-	bool IsHandshakeDone() const { return (status == ISSL_OPEN); }
 	OpenSSL::Profile& GetProfile();
 };
 
@@ -935,13 +958,13 @@ static int OpenSSL::BIOMethod::read(BIO* bio, char* buffer, int size)
 	return ret;
 }
 
-class OpenSSLIOHookProvider : public IOHookProvider
+class OpenSSLIOHookProvider : public SSLIOHookProvider
 {
 	OpenSSL::Profile profile;
 
  public:
 	OpenSSLIOHookProvider(Module* mod, const std::string& profilename, ConfigTag* tag)
-		: IOHookProvider(mod, "ssl/" + profilename, IOHookProvider::IOH_SSL)
+		: SSLIOHookProvider(mod, profilename)
 		, profile(profilename, tag)
 	{
 		ServerInstance->Modules->AddService(*this);
@@ -999,7 +1022,7 @@ class ModuleSSLOpenSSL : public Module
 		}
 		else
 		{
-			ServerInstance->Logs->Log(MODNAME, LOG_DEFAULT, "You have defined an <sslprofile> tag; you should use this in place of \"openssl\" when configuring TLS (SSL) connections in <bind:ssl> or <link:ssl>");
+			ServerInstance->Logs->Log(MODNAME, LOG_DEFAULT, "You have defined an <sslprofile> tag; you should use this in place of \"openssl\" when configuring TLS (SSL) connections in <bind:sslprofile> or <link:sslprofile>");
 			for (ConfigIter i = tags.first; i != tags.second; ++i)
 			{
 				ConfigTag* tag = i->second;
@@ -1063,8 +1086,13 @@ class ModuleSSLOpenSSL : public Module
 		exdataindex = SSL_get_ex_new_index(0, exdatastr, NULL, NULL, NULL);
 		if (exdataindex < 0)
 			throw ModuleException("Failed to register application specific data");
+	}
 
-		ReadProfiles();
+	void ReadConfig(ConfigStatus& status) CXX11_OVERRIDE
+	{
+		ConfigTag* tag = ServerInstance->Config->ConfValue("openssl");
+		if (status.initial || tag->getBool("onrehash"))
+			ReadProfiles();
 	}
 
 	void OnModuleRehash(User* user, const std::string &param) CXX11_OVERRIDE
@@ -1075,11 +1103,11 @@ class ModuleSSLOpenSSL : public Module
 		try
 		{
 			ReadProfiles();
-			ServerInstance->SNO->WriteToSnoMask('a', "TLS (SSL) module OpenSSL rehashed.");
+			ServerInstance->SNO->WriteToSnoMask('a', "OpenSSL TLS (SSL) profiles have been reloaded.");
 		}
 		catch (ModuleException& ex)
 		{
-			ServerInstance->Logs->Log(MODNAME, LOG_DEFAULT, ex.GetReason() + " Not applying settings.");
+			ServerInstance->SNO->WriteToSnoMask('a', "Failed to reload the OpenSSL TLS (SSL) profiles. " + ex.GetReason());
 		}
 	}
 
@@ -1101,7 +1129,7 @@ class ModuleSSLOpenSSL : public Module
 	ModResult OnCheckReady(LocalUser* user) CXX11_OVERRIDE
 	{
 		const OpenSSLIOHook* const iohook = static_cast<OpenSSLIOHook*>(user->eh.GetModHook(this));
-		if ((iohook) && (!iohook->IsHandshakeDone()))
+		if ((iohook) && (!iohook->IsHookReady()))
 			return MOD_RES_DENY;
 		return MOD_RES_PASSTHRU;
 	}
