@@ -3,7 +3,7 @@
  *
  *   Copyright (C) 2018-2020 Matt Schatz <genius3000@g3k.solutions>
  *   Copyright (C) 2018-2019 linuxdaemon <linuxdaemon.irc@gmail.com>
- *   Copyright (C) 2013, 2016-2020 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2013, 2017-2021 Sadie Powell <sadie@witchery.services>
  *   Copyright (C) 2013, 2015-2016 Adam <Adam@anope.org>
  *   Copyright (C) 2012-2016 Attila Molnar <attilamolnar@hush.com>
  *   Copyright (C) 2012, 2018 Robby <robby@chatbelgie.be>
@@ -42,9 +42,19 @@ class DNSBLConfEntry : public refcountbase
 		EnumType type;
 		unsigned long duration;
 		unsigned int bitmask;
+		unsigned int timeout;
 		unsigned char records[256];
-		unsigned long stats_hits, stats_misses;
-		DNSBLConfEntry(): type(A_BITMASK),duration(86400),bitmask(0),stats_hits(0), stats_misses(0) {}
+		unsigned long stats_hits, stats_misses, stats_errors;
+		DNSBLConfEntry()
+			: type(A_BITMASK)
+			, duration(86400)
+			, bitmask(0)
+			, timeout(0)
+			, stats_hits(0)
+			, stats_misses(0)
+			, stats_errors(0)
+		{
+		}
 };
 
 
@@ -61,7 +71,7 @@ class DNSBLResolver : public DNS::Request
 
  public:
 	DNSBLResolver(DNS::Manager *mgr, Module *me, LocalStringExt& match, LocalIntExt& ctr, const std::string &hostname, LocalUser* u, reference<DNSBLConfEntry> conf)
-		: DNS::Request(mgr, me, hostname, DNS::QUERY_A, true)
+		: DNS::Request(mgr, me, hostname, DNS::QUERY_A, true, conf->timeout)
 		, theirsa(u->client_sa)
 		, theiruid(u->uuid)
 		, nameExt(match)
@@ -76,16 +86,7 @@ class DNSBLResolver : public DNS::Request
 		/* Check the user still exists */
 		LocalUser* them = IS_LOCAL(ServerInstance->FindUUID(theiruid));
 		if (!them || them->client_sa != theirsa)
-			return;
-
-		const DNS::ResourceRecord* const ans_record = r->FindAnswerOfType(DNS::QUERY_A);
-		if (!ans_record)
-			return;
-
-		// All replies should be in 127.0.0.0/8
-		if (ans_record->rdata.compare(0, 4, "127.") != 0)
 		{
-			ServerInstance->SNO->WriteGlobalSno('d', "DNSBL: %s returned address outside of acceptable subnet 127.0.0.0/8: %s", ConfEntry->domain.c_str(), ans_record->rdata.c_str());
 			ConfEntry->stats_misses++;
 			return;
 		}
@@ -94,25 +95,51 @@ class DNSBLResolver : public DNS::Request
 		if (i)
 			countExt.set(them, i - 1);
 
-		// Now we calculate the bitmask: 256*(256*(256*a+b)+c)+d
+		// The DNSBL reply must contain an A result.
+		const DNS::ResourceRecord* const ans_record = r->FindAnswerOfType(DNS::QUERY_A);
+		if (!ans_record)
+		{
+			ConfEntry->stats_errors++;
+			ServerInstance->SNO->WriteGlobalSno('d', "%s returned an result with no IPv4 address.",
+				ConfEntry->name.c_str());
+			return;
+		}
 
-		unsigned int bitmask = 0, record = 0;
-		bool match = false;
+		// The DNSBL reply must be a valid IPv4 address.
 		in_addr resultip;
+		if (inet_pton(AF_INET, ans_record->rdata.c_str(), &resultip) != 1)
+		{
+			ConfEntry->stats_errors++;
+			ServerInstance->SNO->WriteGlobalSno('d', "%s returned an invalid IPv4 address: %s",
+				ConfEntry->name.c_str(), ans_record->rdata.c_str());
+			return;
+		}
 
-		inet_pton(AF_INET, ans_record->rdata.c_str(), &resultip);
+		// The DNSBL reply should be in the 127.0.0.0/8 range.
+		if ((resultip.s_addr & 0xFF) != 127)
+		{
+			ConfEntry->stats_errors++;
+			ServerInstance->SNO->WriteGlobalSno('d', "%s returned an IPv4 address which is outside of the 127.0.0.0/8 subnet: %s",
+				ConfEntry->name.c_str(), ans_record->rdata.c_str());
+			return;
+		}
 
+		bool match = false;
+		unsigned int result = 0;
 		switch (ConfEntry->type)
 		{
 			case DNSBLConfEntry::A_BITMASK:
-				bitmask = resultip.s_addr >> 24; /* Last octet (network byte order) */
-				bitmask &= ConfEntry->bitmask;
-				match = (bitmask != 0);
-			break;
+			{
+				result = (resultip.s_addr >> 24) & ConfEntry->bitmask;
+				match = (result != 0);
+				break;
+			}
 			case DNSBLConfEntry::A_RECORD:
-				record = resultip.s_addr >> 24; /* Last octet */
-				match = (ConfEntry->records[record] == 1);
-			break;
+			{
+				result = resultip.s_addr >> 24;
+				match = (ConfEntry->records[result] == 1);
+				break;
+			}
 		}
 
 		if (match)
@@ -155,11 +182,11 @@ class DNSBLResolver : public DNS::Request
 				case DNSBLConfEntry::I_KLINE:
 				{
 					KLine* kl = new KLine(ServerInstance->Time(), ConfEntry->duration, ServerInstance->Config->ServerName.c_str(), reason.c_str(),
-							"*", them->GetIPString());
+							them->GetBanIdent(), them->GetIPString());
 					if (ServerInstance->XLines->AddLine(kl,NULL))
 					{
-						ServerInstance->SNO->WriteToSnoMask('x', "K-line added due to DNSBL match on *@%s to expire in %s (on %s): %s",
-							them->GetIPString().c_str(), InspIRCd::DurationString(kl->duration).c_str(),
+						ServerInstance->SNO->WriteToSnoMask('x', "K-line added due to DNSBL match on %s to expire in %s (on %s): %s",
+							kl->Displayable().c_str(), InspIRCd::DurationString(kl->duration).c_str(),
 							InspIRCd::TimeString(kl->expiry).c_str(), reason.c_str());
 						ServerInstance->XLines->ApplyLines();
 					}
@@ -173,11 +200,11 @@ class DNSBLResolver : public DNS::Request
 				case DNSBLConfEntry::I_GLINE:
 				{
 					GLine* gl = new GLine(ServerInstance->Time(), ConfEntry->duration, ServerInstance->Config->ServerName.c_str(), reason.c_str(),
-							"*", them->GetIPString());
+							them->GetBanIdent(), them->GetIPString());
 					if (ServerInstance->XLines->AddLine(gl,NULL))
 					{
-						ServerInstance->SNO->WriteToSnoMask('x', "G-line added due to DNSBL match on *@%s to expire in %s (on %s): %s",
-							them->GetIPString().c_str(), InspIRCd::DurationString(gl->duration).c_str(),
+						ServerInstance->SNO->WriteToSnoMask('x', "G-line added due to DNSBL match on %s to expire in %s (on %s): %s",
+							gl->Displayable().c_str(), InspIRCd::DurationString(gl->duration).c_str(),
 							InspIRCd::TimeString(gl->expiry).c_str(), reason.c_str());
 						ServerInstance->XLines->ApplyLines();
 					}
@@ -212,7 +239,7 @@ class DNSBLResolver : public DNS::Request
 			}
 
 			ServerInstance->SNO->WriteGlobalSno('d', "Connecting user %s (%s) detected as being on the '%s' DNS blacklist with result %d",
-				them->GetFullRealHost().c_str(), them->GetIPString().c_str(), ConfEntry->name.c_str(), (ConfEntry->type==DNSBLConfEntry::A_BITMASK) ? bitmask : record);
+				them->GetFullRealHost().c_str(), them->GetIPString().c_str(), ConfEntry->name.c_str(), result);
 		}
 		else
 			ConfEntry->stats_misses++;
@@ -220,6 +247,20 @@ class DNSBLResolver : public DNS::Request
 
 	void OnError(const DNS::Query *q) CXX11_OVERRIDE
 	{
+		bool is_miss = true;
+		switch (q->error)
+		{
+			case DNS::ERROR_NO_RECORDS:
+			case DNS::ERROR_DOMAIN_NOT_FOUND:
+				ConfEntry->stats_misses++;
+				break;
+
+			default:
+				ConfEntry->stats_errors++;
+				is_miss = false;
+				break;
+		}
+
 		LocalUser* them = IS_LOCAL(ServerInstance->FindUUID(theiruid));
 		if (!them || them->client_sa != theirsa)
 			return;
@@ -228,11 +269,8 @@ class DNSBLResolver : public DNS::Request
 		if (i)
 			countExt.set(them, i - 1);
 
-		if (q->error == DNS::ERROR_NO_RECORDS || q->error == DNS::ERROR_DOMAIN_NOT_FOUND)
-		{
-			ConfEntry->stats_misses++;
+		if (is_miss)
 			return;
-		}
 
 		ServerInstance->SNO->WriteGlobalSno('d', "An error occurred whilst checking whether %s (%s) is on the '%s' DNS blacklist: %s",
 			them->GetFullRealHost().c_str(), them->GetIPString().c_str(), ConfEntry->name.c_str(), this->manager->GetErrorStr(q->error).c_str());
@@ -307,6 +345,7 @@ class ModuleDNSBL : public Module, public Stats::EventListener
 			e->host = tag->getString("host");
 			e->reason = tag->getString("reason", "Your IP has been blacklisted.", 1);
 			e->domain = tag->getString("domain");
+			e->timeout = tag->getDuration("timeout", 0);
 
 			if (stdalgo::string::equalsci(tag->getString("type"), "bitmask"))
 			{
@@ -464,20 +503,22 @@ class ModuleDNSBL : public Module, public Stats::EventListener
 		if (stats.GetSymbol() != 'd')
 			return MOD_RES_PASSTHRU;
 
-		unsigned long total_hits = 0, total_misses = 0;
-
+		unsigned long total_hits = 0;
+		unsigned long total_misses = 0;
+		unsigned long total_errors = 0;
 		for (std::vector<reference<DNSBLConfEntry> >::const_iterator i = DNSBLConfEntries.begin(); i != DNSBLConfEntries.end(); ++i)
 		{
 			total_hits += (*i)->stats_hits;
 			total_misses += (*i)->stats_misses;
+			total_errors += (*i)->stats_errors;
 
-			stats.AddRow(304, "DNSBLSTATS DNSbl \"" + (*i)->name + "\" had " +
-					ConvToStr((*i)->stats_hits) + " hits and " + ConvToStr((*i)->stats_misses) + " misses");
+			stats.AddRow(304, InspIRCd::Format("DNSBLSTATS \"%s\" had %lu hits, %lu misses, and %lu errors",
+				(*i)->name.c_str(), (*i)->stats_hits, (*i)->stats_misses, (*i)->stats_errors));
 		}
 
 		stats.AddRow(304, "DNSBLSTATS Total hits: " + ConvToStr(total_hits));
 		stats.AddRow(304, "DNSBLSTATS Total misses: " + ConvToStr(total_misses));
-
+		stats.AddRow(304, "DNSBLSTATS Total errors: " + ConvToStr(total_errors));
 		return MOD_RES_PASSTHRU;
 	}
 };
