@@ -2,7 +2,7 @@
  * InspIRCd -- Internet Relay Chat Daemon
  *
  *   Copyright (C) 2020 Matt Schatz <genius3000@g3k.solutions>
- *   Copyright (C) 2019 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2019, 2021 Sadie Powell <sadie@witchery.services>
  *
  * This file is part of InspIRCd.  InspIRCd is free software: you can
  * redistribute it and/or modify it under the terms of the GNU General Public
@@ -22,12 +22,6 @@
 #include "modules/geolocation.h"
 #include "modules/whois.h"
 
-enum
-{
-	// InspIRCd-specific.
-	RPL_WHOISCOUNTRY = 344
-};
-
 class ModuleGeoBan
 	: public Module
 	, public Whois::EventListener
@@ -44,7 +38,7 @@ class ModuleGeoBan
 
 	Version GetVersion() CXX11_OVERRIDE
 	{
-		return Version("Adds extended ban G which matches against two letter country codes.", VF_OPTCOMMON|VF_VENDOR);
+		return Version("Adds extended ban G: (country) which matches against two letter country codes.", VF_OPTCOMMON|VF_VENDOR);
 	}
 
 	void On005Numeric(std::map<std::string, std::string>& tokens) CXX11_OVERRIDE
