@@ -3,7 +3,7 @@
  *
  *   Copyright (C) 2019 linuxdaemon <linuxdaemon.irc@gmail.com>
  *   Copyright (C) 2018 edef <edef@edef.eu>
- *   Copyright (C) 2013-2014, 2017-2020 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2013-2014, 2017-2021 Sadie Powell <sadie@witchery.services>
  *   Copyright (C) 2012-2016 Attila Molnar <attilamolnar@hush.com>
  *   Copyright (C) 2012 Robby <robby@chatbelgie.be>
  *   Copyright (C) 2009 Uli Schlachter <psychon@inspircd.org>
@@ -123,6 +123,8 @@ class HttpServerSocket : public BufferedSocket, public Timer, public insp::intru
 		parser_settings.on_message_begin = Callback<&HttpServerSocket::OnMessageBegin>;
 		parser_settings.on_url = DataCallback<&HttpServerSocket::OnUrl>;
 		parser_settings.on_header_field = DataCallback<&HttpServerSocket::OnHeaderField>;
+		parser_settings.on_header_value = DataCallback<&HttpServerSocket::OnHeaderValue>;
+		parser_settings.on_headers_complete = Callback<&HttpServerSocket::OnHeadersComplete>;
 		parser_settings.on_body = DataCallback<&HttpServerSocket::OnBody>;
 		parser_settings.on_message_complete = Callback<&HttpServerSocket::OnMessageComplete>;
 	}
@@ -264,14 +266,18 @@ class HttpServerSocket : public BufferedSocket, public Timer, public insp::intru
 		Close();
 	}
 
-	void SendHTTPError(unsigned int response)
+	void SendHTTPError(unsigned int response, const char* errstr = NULL)
 	{
+		if (!errstr)
+			errstr = http_status_str((http_status)response);
+
+		ServerInstance->Logs->Log(MODNAME, LOG_DEBUG, "Sending HTTP error %u: %s", response, errstr);
 		static HTTPHeaders empty;
 		std::string data = InspIRCd::Format(
 			"<html><head></head><body style='font-family: sans-serif; text-align: center'>"
 			"<h1 style='font-size: 48pt'>Error %u</h1><h2 style='font-size: 24pt'>%s</h2><hr>"
 			"<small>Powered by <a href='https://www.inspircd.org'>InspIRCd</a></small></body></html>",
-			response, http_status_str((http_status)response));
+			response, errstr);
 
 		Page(data, response, &empty);
 	}
@@ -303,8 +309,10 @@ class HttpServerSocket : public BufferedSocket, public Timer, public insp::intru
 		if (parser.upgrade || HTTP_PARSER_ERRNO(&parser))
 			return;
 		http_parser_execute(&parser, &parser_settings, recvq.data(), recvq.size());
-		if (parser.upgrade || HTTP_PARSER_ERRNO(&parser))
+		if (parser.upgrade)
 			SendHTTPError(status_code ? status_code : 400);
+		else if (HTTP_PARSER_ERRNO(&parser))
+			SendHTTPError(status_code ? status_code : 400, http_errno_description((http_errno)parser.http_errno));
 	}
 
 	void ServeData()
@@ -345,7 +353,32 @@ class HttpServerSocket : public BufferedSocket, public Timer, public insp::intru
 			return false;
 
 		if (url.field_set & (1 << UF_PATH))
-			out.path = uri.substr(url.field_data[UF_PATH].off, url.field_data[UF_PATH].len);
+		{
+			// Normalise the path.
+			std::vector<std::string> pathsegments;
+			irc::sepstream pathstream(uri.substr(url.field_data[UF_PATH].off, url.field_data[UF_PATH].len), '/');
+			for (std::string pathsegment; pathstream.GetToken(pathsegment); )
+			{
+				if (pathsegment == ".")
+				{
+					// Stay at the current level.
+					continue;
+				}
+
+				if (pathsegment == "..")
+				{
+					// Traverse up to the previous level.
+					if (!pathsegments.empty())
+						pathsegments.pop_back();
+					continue;
+				}
+
+				pathsegments.push_back(pathsegment);
+			}
+
+			out.path.reserve(url.field_data[UF_PATH].len);
+			out.path.append("/").append(stdalgo::string::join(pathsegments, '/'));
+		}
 
 		if (url.field_set & (1 << UF_FRAGMENT))
 			out.fragment = uri.substr(url.field_data[UF_FRAGMENT].off, url.field_data[UF_FRAGMENT].len);
