@@ -1,16 +1,17 @@
 /*
  * InspIRCd -- Internet Relay Chat Daemon
  *
+ *   Copyright (C) 2021 Herman <GermanAizek@yandex.ru>
  *   Copyright (C) 2019 Matt Schatz <genius3000@g3k.solutions>
- *   Copyright (C) 2013, 2015, 2017, 2020 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2013, 2015, 2017, 2020-2021 Sadie Powell <sadie@witchery.services>
  *   Copyright (C) 2012-2016 Attila Molnar <attilamolnar@hush.com>
  *   Copyright (C) 2012, 2019 Robby <robby@chatbelgie.be>
  *   Copyright (C) 2011 jackmcbarn <jackmcbarn@inspircd.org>
  *   Copyright (C) 2009-2010 Daniel De Graaf <danieldg@inspircd.org>
+ *   Copyright (C) 2009-2010 Craig Edwards <brain@inspircd.org>
  *   Copyright (C) 2009 Uli Schlachter <psychon@inspircd.org>
  *   Copyright (C) 2009 Robin Burchell <robin+git@viroteck.net>
  *   Copyright (C) 2009 Dennis Friis <peavey@inspircd.org>
- *   Copyright (C) 2009 Craig Edwards <brain@inspircd.org>
  *
  * This file is part of InspIRCd.  InspIRCd is free software: you can
  * redistribute it and/or modify it under the terms of the GNU General Public
@@ -40,12 +41,11 @@ class lwbNickHandler
 	static bool Call(const std::string&);
 };
 
-								 /*,m_reverse_additionalUp[256];*/
 static unsigned char m_reverse_additional[256],m_additionalMB[256],m_additionalUtf8[256],m_additionalUtf8range[256],m_additionalUtf8interval[256];
 
-char utf8checkrest(unsigned char * mb, unsigned char cnt)
+char utf8checkrest(unsigned char* mb, unsigned char cnt)
 {
-	for (unsigned char * tmp=mb; tmp<mb+cnt; tmp++)
+	for (unsigned char* tmp=mb; tmp<mb+cnt; tmp++)
 	{
 		/* & is faster! -- Phoenix (char & b11000000 == b10000000) */
 		if ((*tmp & 192) != 128)
@@ -90,7 +90,7 @@ bool lwbNickHandler::Call(const std::string& nick)
 		{
 			/* otherwise let's take a look at the current character and the following one */
 			bool found = false;
-			for(unsigned char * mb = m_additionalMB; (*mb) && (mb < m_additionalMB + sizeof(m_additionalMB)); mb += 4)
+			for(unsigned char* mb = m_additionalMB; (*mb) && (mb < m_additionalMB + sizeof(m_additionalMB)); mb += 4)
 			{
 				if ( (i[0] >= mb[0]) && (i[0] <= mb[1]) && (i[1] >= mb[2]) && (i[1] <= mb[3]) )
 				{
@@ -119,19 +119,19 @@ bool lwbNickHandler::Call(const std::string& nick)
 			continue;
 
 		/* 3.1. Check against a simple UTF-8 characters enumeration */
-		int cursize, cursize2, ncursize = utf8size((unsigned char *)i);
+		int cursize, cursize2, ncursize = utf8size((unsigned char*)i);
 		/* do check only if current multibyte character is valid UTF-8 only */
 		if (ncursize != -1)
 		{
 			bool found = false;
-			for (unsigned char * mb = m_additionalUtf8; (utf8size(mb) != -1) && (mb < m_additionalUtf8 + sizeof(m_additionalUtf8)); mb += cursize)
+			for (unsigned char* mb = m_additionalUtf8; (utf8size(mb) != -1) && (mb < m_additionalUtf8 + sizeof(m_additionalUtf8)); mb += cursize)
 			{
 				cursize = utf8size(mb);
 				/* Size differs? Pick the next! */
 				if (cursize != ncursize)
 					continue;
 
-				if (!strncmp(i, (char *)mb, cursize))
+				if (!strncmp(i, (char*)mb, cursize))
 				{
 					i += cursize - 1;
 					p += cursize - 1;
@@ -144,7 +144,7 @@ bool lwbNickHandler::Call(const std::string& nick)
 
 			/* 3.2. Check against an UTF-8 ranges: <start character> and <length of the range>. */
 			found = false;
-			for (unsigned char * mb = m_additionalUtf8range; (utf8size(mb) != -1) && (mb < m_additionalUtf8range + sizeof(m_additionalUtf8range)); mb += cursize + 1)
+			for (unsigned char* mb = m_additionalUtf8range; (utf8size(mb) != -1) && (mb < m_additionalUtf8range + sizeof(m_additionalUtf8range)); mb += cursize + 1)
 			{
 				cursize = utf8size(mb);
 				/* Size differs (or lengthbyte is zero)? Pick the next! */
@@ -152,7 +152,7 @@ bool lwbNickHandler::Call(const std::string& nick)
 					continue;
 
 				unsigned char uright[5] = {0,0,0,0,0}, range = mb[cursize] - 1;
-				strncpy((char* ) uright, (char *) mb, cursize);
+				strncpy((char*) uright, (char*) mb, cursize);
 
 				for (int temp = cursize - 1; (temp >= 0) && range; --temp)
 				{
@@ -176,7 +176,7 @@ bool lwbNickHandler::Call(const std::string& nick)
 					}
 				}
 
-				if ((strncmp(i, (char *) mb, cursize) >= 0) && (strncmp(i, (char *) uright, cursize) <= 0))
+				if ((strncmp(i, (char*) mb, cursize) >= 0) && (strncmp(i, (char*) uright, cursize) <= 0))
 				{
 					i += cursize - 1;
 					p += cursize - 1;
@@ -189,7 +189,7 @@ bool lwbNickHandler::Call(const std::string& nick)
 
 			/* 3.3. Check against an UTF-8 intervals: <start character> and <end character>. */
 			found = false;
-			for (unsigned char * mb = m_additionalUtf8interval; (utf8size(mb) != -1) && (utf8size(mb+utf8size(mb)) != -1)
+			for (unsigned char* mb = m_additionalUtf8interval; (utf8size(mb) != -1) && (utf8size(mb+utf8size(mb)) != -1)
 				&& (mb < m_additionalUtf8interval + sizeof(m_additionalUtf8interval)); mb += (cursize+cursize2) )
 			{
 				cursize = utf8size(mb);
@@ -200,7 +200,7 @@ bool lwbNickHandler::Call(const std::string& nick)
 
 				unsigned char* uright = mb + cursize;
 
-				if ((strncmp(i, (char *) mb, minlen) >= 0) && (strncmp(i, (char *) uright, minlen2) <= 0))
+				if ((strncmp(i, (char*) mb, minlen) >= 0) && (strncmp(i, (char*) uright, minlen2) <= 0))
 				{
 					i += cursize - 1;
 					p += cursize - 1;
@@ -285,7 +285,7 @@ class ModuleNationalChars : public Module
 		if(charset[0] != '/')
 			charset.insert(0, "../locales/");
 #endif
-		unsigned char * tables[8] = { m_additional, m_additionalMB, m_additionalUp, m_lower, m_upper, m_additionalUtf8, m_additionalUtf8range, m_additionalUtf8interval };
+		unsigned char* tables[8] = { m_additional, m_additionalMB, m_additionalUp, m_lower, m_upper, m_additionalUtf8, m_additionalUtf8range, m_additionalUtf8interval };
 		if (!loadtables(charset, tables, 8, 5))
 			throw ModuleException("The locale file failed to load. Check your log file for more information.");
 		forcequit = tag->getBool("forcequit");
@@ -293,7 +293,7 @@ class ModuleNationalChars : public Module
 		CheckRehash();
 	}
 
-	void CheckForceQuit(const char * message)
+	void CheckForceQuit(const char* message)
 	{
 		if (!forcequit)
 			return;
@@ -327,15 +327,15 @@ class ModuleNationalChars : public Module
 	}
 
 	/*make an array to check against it 8bit characters a bit faster. Whether allowed or uppercase (for your needs).*/
-	void makereverse(unsigned char * from, unsigned  char * to, unsigned int cnt)
+	void makereverse(unsigned char* from, unsigned char* to, unsigned int cnt)
 	{
 		memset(to, 0, cnt);
-		for(unsigned char * n=from; (*n) && ((*n)<cnt) && (n<from+cnt); n++)
+		for(unsigned char* n=from; (*n) && ((*n)<cnt) && (n<from+cnt); n++)
 			to[*n] = 1;
 	}
 
 	/*so Bynets Unreal distribution stuff*/
-	bool loadtables(std::string filename, unsigned char ** tables, unsigned char cnt, char faillimit)
+	bool loadtables(const std::string& filename, unsigned char** tables, unsigned char cnt, char faillimit)
 	{
 		std::ifstream ifs(ServerInstance->Config->Paths.PrependConfig(filename).c_str());
 		if (ifs.fail())
@@ -364,7 +364,7 @@ class ModuleNationalChars : public Module
 		return true;
 	}
 
-	unsigned char symtoi(const char *t,unsigned char base)
+	unsigned char symtoi(const char* t,unsigned char base)
 	/* base = 16 for hexadecimal, 10 for decimal, 8 for octal ;) */
 	{
 		unsigned char tmp = 0, current;
@@ -382,7 +382,7 @@ class ModuleNationalChars : public Module
 		return tmp;
 	}
 
-	int loadtable(std::ifstream &ifs , unsigned char *chartable, unsigned int maxindex)
+	int loadtable(std::ifstream& ifs , unsigned char* chartable, unsigned int maxindex)
 	{
 		std::string buf;
 		getline(ifs, buf);
@@ -390,7 +390,7 @@ class ModuleNationalChars : public Module
 		unsigned int i = 0;
 		int fail = 0;
 
-		buf.erase(buf.find_last_not_of("\n") + 1);
+		buf.erase(buf.find_last_not_of('\n') + 1);
 
 		if (buf[0] == '.')	/* simple plain-text string after dot */
 		{
@@ -417,7 +417,7 @@ class ModuleNationalChars : public Module
 					if (*p == '0')
 					{
 						if (p[1] == 'x')
-							 /* hex with the leading "0x" */
+							/* hex with the leading "0x" */
 							chartable[i] = symtoi(p + 2, 16);
 						else
 							chartable[i] = symtoi(p + 1, 8);
@@ -426,12 +426,13 @@ class ModuleNationalChars : public Module
 					else if (*p == 'x')
 					{
 						chartable[i] = symtoi(p + 1, 16);
-					}else	 /* decimal form */
+					}
+					else /* decimal form */
 					{
 						chartable[i] = symtoi(p, 10);
 					}
 				}
-				else		 /* plain-text char between '' */
+				else /* plain-text char between '' */
 				{
 					if (*(p + 1) == '\\')
 					{
