@@ -1,10 +1,12 @@
 /*
  * InspIRCd -- Internet Relay Chat Daemon
  *
+ *   Copyright (C) 2021 Herman <GermanAizek@yandex.ru>
+ *   Copyright (C) 2020 satmd <satmd@satmd.de>
  *   Copyright (C) 2017 B00mX0r <b00mx0r@aureus.pw>
  *   Copyright (C) 2017 Adam <Adam@anope.org>
  *   Copyright (C) 2016 Sheogorath <sheogorath@shivering-isles.com>
- *   Copyright (C) 2013, 2017, 2020 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2013, 2017, 2020-2021 Sadie Powell <sadie@witchery.services>
  *   Copyright (C) 2013 Daniel Vassdal <shutter@canternet.org>
  *   Copyright (C) 2012-2015 Attila Molnar <attilamolnar@hush.com>
  *   Copyright (C) 2012 Shawn Smith <ShawnSmith0828@gmail.com>
@@ -13,7 +15,7 @@
  *   Copyright (C) 2009 Uli Schlachter <psychon@inspircd.org>
  *   Copyright (C) 2008 Robin Burchell <robin+git@viroteck.net>
  *   Copyright (C) 2007-2008 Dennis Friis <peavey@inspircd.org>
- *   Copyright (C) 2006, 2008, 2010 Craig Edwards <brain@inspircd.org>
+ *   Copyright (C) 2004, 2006, 2008, 2010 Craig Edwards <brain@inspircd.org>
  *
  * This file is part of InspIRCd.  InspIRCd is free software: you can
  * redistribute it and/or modify it under the terms of the GNU General Public
@@ -109,7 +111,8 @@ class ModuleOverride : public Module
 
 	void On005Numeric(std::map<std::string, std::string>& tokens) CXX11_OVERRIDE
 	{
-		tokens["OVERRIDE"];
+		if (UmodeEnabled)
+			tokens["OVERRIDE"] = ConvToStr(ou.GetModeChar());
 	}
 
 	bool CanOverride(User* source, const char* token)
@@ -120,7 +123,7 @@ class ModuleOverride : public Module
 
 		std::string tokenlist = source->oper->getConfig("override");
 		// its defined or * is set, return its value as a boolean for if the token is set
-		return ((tokenlist.find(token, 0) != std::string::npos) || (tokenlist.find("*", 0) != std::string::npos));
+		return ((tokenlist.find(token, 0) != std::string::npos) || (tokenlist.find('*', 0) != std::string::npos));
 	}
 
 
@@ -170,7 +173,7 @@ class ModuleOverride : public Module
 
 		if (CanOverride(source, "MODE"))
 		{
-			std::string msg = source->nick + " overriding modes: ";
+			std::string msg = source->nick + " used oper override to set modes on " + channel->name + ": ";
 
 			// Construct a MODE string in the old format for sending it as a snotice
 			std::string params;
