@@ -1,10 +1,12 @@
 /*
  * InspIRCd -- Internet Relay Chat Daemon
  *
+ *   Copyright (C) 2021 iwalkalone <iwalkalone69@gmail.com>
+ *   Copyright (C) 2021 David Schultz <me@zpld.me>
  *   Copyright (C) 2019 Robby <robby@chatbelgie.be>
  *   Copyright (C) 2018-2019 linuxdaemon <linuxdaemon.irc@gmail.com>
  *   Copyright (C) 2018 Matt Schatz <genius3000@g3k.solutions>
- *   Copyright (C) 2017-2019 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2017-2019, 2021 Sadie Powell <sadie@witchery.services>
  *   Copyright (C) 2015 James Lu <GLolol@overdrivenetworks.com>
  *   Copyright (C) 2013-2015 Attila Molnar <attilamolnar@hush.com>
  *   Copyright (C) 2013 Daniel Vassdal <shutter@canternet.org>
@@ -29,7 +31,7 @@
 class ChannelSettings
 {
  public:
- 	enum RepeatAction
+	enum RepeatAction
 	{
 		ACT_KICK,
 		ACT_BLOCK,
@@ -90,6 +92,7 @@ class RepeatMode : public ParamMode<RepeatMode, SimpleExtItem<ChannelSettings> >
 		unsigned int MaxBacklog;
 		unsigned int MaxDiff;
 		unsigned int MaxMessageSize;
+		std::string KickMessage;
 		ModuleSettings() : MaxLines(0), MaxSecs(0), MaxBacklog(0), MaxDiff() { }
 	};
 
@@ -251,6 +254,8 @@ class RepeatMode : public ParamMode<RepeatMode, SimpleExtItem<ChannelSettings> >
 		if (newsize > ServerInstance->Config->Limits.MaxLine)
 			newsize = ServerInstance->Config->Limits.MaxLine;
 		Resize(newsize);
+
+		ms.KickMessage = conf->getString("kickmessage", "Repeat flood");
 	}
 
 	std::string GetModuleSettings() const
@@ -258,6 +263,11 @@ class RepeatMode : public ParamMode<RepeatMode, SimpleExtItem<ChannelSettings> >
 		return ConvToStr(ms.MaxLines) + ":" + ConvToStr(ms.MaxSecs) + ":" + ConvToStr(ms.MaxDiff) + ":" + ConvToStr(ms.MaxBacklog);
 	}
 
+	std::string GetKickMessage() const
+	{
+		return ms.KickMessage;
+	}
+
 	void SerializeParam(Channel* chan, const ChannelSettings* chset, std::string& out)
 	{
 		chset->serialize(out);
@@ -354,12 +364,15 @@ class RepeatMode : public ParamMode<RepeatMode, SimpleExtItem<ChannelSettings> >
 
 class RepeatModule : public Module
 {
+ private:
+	ChanModeReference banmode;
 	CheckExemption::EventProvider exemptionprov;
 	RepeatMode rm;
 
  public:
 	RepeatModule()
-		: exemptionprov(this)
+		: banmode(this, "ban")
+		, exemptionprov(this)
 		, rm(this)
 	{
 	}
@@ -387,6 +400,9 @@ class RepeatModule : public Module
 		if (res == MOD_RES_ALLOW)
 			return MOD_RES_PASSTHRU;
 
+		if (user->HasPrivPermission("channels/ignore-repeat"))
+			return MOD_RES_PASSTHRU;
+
 		if (rm.MatchLine(memb, settings, details.text))
 		{
 			if (settings->Action == ChannelSettings::ACT_BLOCK)
@@ -398,11 +414,11 @@ class RepeatModule : public Module
 			if (settings->Action == ChannelSettings::ACT_BAN)
 			{
 				Modes::ChangeList changelist;
-				changelist.push_add(ServerInstance->Modes->FindMode('b', MODETYPE_CHANNEL), "*!*@" + user->GetDisplayedHost());
+				changelist.push_add(*banmode, "*!" + user->GetBanIdent() + "@" + user->GetDisplayedHost());
 				ServerInstance->Modes->Process(ServerInstance->FakeClient, chan, NULL, changelist);
 			}
 
-			memb->chan->KickUser(ServerInstance->FakeClient, user, "Repeat flood");
+			memb->chan->KickUser(ServerInstance->FakeClient, user, rm.GetKickMessage());
 			return MOD_RES_DENY;
 		}
 		return MOD_RES_PASSTHRU;
