@@ -1,6 +1,7 @@
 /*
  * InspIRCd -- Internet Relay Chat Daemon
  *
+ *   Copyright (C) 2021 Herman <GermanAizek@yandex.ru>
  *   Copyright (C) 2016 Adam <Adam@anope.org>
  *   Copyright (C) 2014 Mantas Mikulėnas <grawity@gmail.com>
  *   Copyright (C) 2013-2016, 2018 Attila Molnar <attilamolnar@hush.com>
@@ -194,6 +195,7 @@ class SaslAuthenticator
 	void SendHostIP(UserCertificateAPI& sslapi)
 	{
 		std::vector<std::string> params;
+		params.reserve(3);
 		params.push_back(user->GetRealHost());
 		params.push_back(user->GetIPString());
 		params.push_back(sslapi && sslapi->GetCertificate(user) ? "S" : "P");
@@ -213,7 +215,7 @@ class SaslAuthenticator
 		params.push_back(method);
 
 		const std::string fp = sslapi ? sslapi->GetFingerprint(user) : "";
-		if (fp.size())
+		if (!fp.empty())
 			params.push_back(fp);
 
 		SendSASL(user, "*", 'S', params);
@@ -235,11 +237,11 @@ class SaslAuthenticator
 	{
 		switch (this->state)
 		{
-		 case SASL_INIT:
+		case SASL_INIT:
 			this->agent = msg[0];
 			this->state = SASL_COMM;
 			/* fall through */
-		 case SASL_COMM:
+		case SASL_COMM:
 			if (msg[0] != this->agent)
 				return this->state;
 
@@ -251,10 +253,12 @@ class SaslAuthenticator
 				ClientProtocol::Message authmsg("AUTHENTICATE");
 				authmsg.PushParamRef(msg[3]);
 
-				ClientProtocol::Event authevent(*g_protoev, authmsg);
 				LocalUser* const localuser = IS_LOCAL(user);
 				if (localuser)
+				{
+					ClientProtocol::Event authevent(*g_protoev, authmsg);
 					localuser->Send(authevent);
+				}
 			}
 			else if (msg[2] == "D")
 			{
@@ -267,9 +271,9 @@ class SaslAuthenticator
 				ServerInstance->Logs->Log(MODNAME, LOG_DEFAULT, "Services sent an unknown SASL message \"%s\" \"%s\"", msg[2].c_str(), msg[3].c_str());
 
 			break;
-		 case SASL_DONE:
+		case SASL_DONE:
 			break;
-		 default:
+		default:
 			ServerInstance->Logs->Log(MODNAME, LOG_DEFAULT, "WTF: SaslState is not a known state (%d)", this->state);
 			break;
 		}
@@ -301,16 +305,16 @@ class SaslAuthenticator
 
 		switch (this->result)
 		{
-		 case SASL_OK:
+		case SASL_OK:
 			this->user->WriteNumeric(RPL_SASLSUCCESS, "SASL authentication successful");
 			break;
-		 case SASL_ABORT:
+		case SASL_ABORT:
 			this->user->WriteNumeric(ERR_SASLABORTED, "SASL authentication aborted");
 			break;
-		 case SASL_FAIL:
+		case SASL_FAIL:
 			this->user->WriteNumeric(ERR_SASLFAIL, "SASL authentication failed");
 			break;
-		 default:
+		default:
 			break;
 		}
 
@@ -321,8 +325,8 @@ class SaslAuthenticator
 class CommandAuthenticate : public SplitCommand
 {
  private:
-	 // The maximum length of an AUTHENTICATE request.
-	 static const size_t MAX_AUTHENTICATE_SIZE = 400;
+	// The maximum length of an AUTHENTICATE request.
+	static const size_t MAX_AUTHENTICATE_SIZE = 400;
 
  public:
 	SimpleExtItem<SaslAuthenticator>& authExt;
