@@ -2,14 +2,14 @@
  * InspIRCd -- Internet Relay Chat Daemon
  *
  *   Copyright (C) 2019 linuxdaemon <linuxdaemon.irc@gmail.com>
- *   Copyright (C) 2013, 2017-2020 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2013, 2017-2021 Sadie Powell <sadie@witchery.services>
  *   Copyright (C) 2012-2015 Attila Molnar <attilamolnar@hush.com>
  *   Copyright (C) 2012, 2019 Robby <robby@chatbelgie.be>
  *   Copyright (C) 2012 Shawn Smith <ShawnSmith0828@gmail.com>
  *   Copyright (C) 2009-2010 Daniel De Graaf <danieldg@inspircd.org>
  *   Copyright (C) 2009 Uli Schlachter <psychon@inspircd.org>
- *   Copyright (C) 2008 Robin Burchell <robin+git@viroteck.net>
  *   Copyright (C) 2007 Dennis Friis <peavey@inspircd.org>
+ *   Copyright (C) 2006, 2008 Robin Burchell <robin+git@viroteck.net>
  *   Copyright (C) 2006, 2008 Craig Edwards <brain@inspircd.org>
  *
  * This file is part of InspIRCd.  InspIRCd is free software: you can
@@ -35,12 +35,6 @@
 
 enum
 {
-	// From UnrealIRCd.
-	RPL_WHOISREGNICK = 307,
-
-	// From ircu.
-	RPL_WHOISACCOUNT = 330,
-
 	// From ircd-hybrid?
 	ERR_NEEDREGGEDNICK = 477,
 
@@ -154,6 +148,7 @@ class ModuleServicesAccount
 	SimpleUserModeHandler regdeafmode;
 	Channel_r chanregmode;
 	User_r userregmode;
+	AccountExtItem accountid;
 	AccountExtItemImpl accountname;
 	bool checking_ban;
 
@@ -168,6 +163,7 @@ class ModuleServicesAccount
 		, regdeafmode(this, "regdeaf", 'R')
 		, chanregmode(this)
 		, userregmode(this)
+		, accountid("accountid", ExtensionItem::EXT_USER, this)
 		, accountname(this)
 		, checking_ban(false)
 	{
@@ -215,30 +211,30 @@ class ModuleServicesAccount
 		{
 			case MessageTarget::TYPE_CHANNEL:
 			{
-				Channel* targchan = target.Get<Channel>();
+				Channel* targetchan = target.Get<Channel>();
 
-				if (!targchan->IsModeSet(regmoderatedmode) || is_registered)
+				if (!targetchan->IsModeSet(regmoderatedmode) || is_registered)
 					return MOD_RES_PASSTHRU;
 
-				if (CheckExemption::Call(exemptionprov, user, targchan, "regmoderated") == MOD_RES_ALLOW)
+				if (CheckExemption::Call(exemptionprov, user, targetchan, "regmoderated") == MOD_RES_ALLOW)
 					return MOD_RES_PASSTHRU;
 
 				// User is messaging a +M channel and is not registered or exempt.
-				user->WriteNumeric(ERR_NEEDREGGEDNICK, targchan->name, "You need to be identified to a registered account to message this channel");
+				user->WriteNumeric(ERR_NEEDREGGEDNICK, targetchan->name, "You need to be identified to a registered account to message this channel");
 				return MOD_RES_DENY;
 				break;
 			}
 			case MessageTarget::TYPE_USER:
 			{
-				User* targuser = target.Get<User>();
-				if (!targuser->IsModeSet(regdeafmode)  || is_registered)
+				User* targetuser = target.Get<User>();
+				if (!targetuser->IsModeSet(regdeafmode)  || is_registered)
 					return MOD_RES_PASSTHRU;
 
-				if (calleridapi && calleridapi->IsOnAcceptList(user, targuser))
+				if (calleridapi && calleridapi->IsOnAcceptList(user, targetuser))
 					return MOD_RES_PASSTHRU;
 
 				// User is messaging a +R user and is not registered or on an accept list.
-				user->WriteNumeric(ERR_NEEDREGGEDNICK, targuser->nick, "You need to be identified to a registered account to message this user");
+				user->WriteNumeric(ERR_NEEDREGGEDNICK, targetuser->nick, "You need to be identified to a registered account to message this user");
 				return MOD_RES_DENY;
 				break;
 			}
