@@ -1,9 +1,10 @@
 /*
  * InspIRCd -- Internet Relay Chat Daemon
  *
+ *   Copyright (C) 2021 Herman <GermanAizek@yandex.ru>
  *   Copyright (C) 2020 Matt Schatz <genius3000@g3k.solutions>
  *   Copyright (C) 2019 linuxdaemon <linuxdaemon.irc@gmail.com>
- *   Copyright (C) 2013, 2017-2020 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2013, 2017-2021 Sadie Powell <sadie@witchery.services>
  *   Copyright (C) 2013, 2016 Adam <Adam@anope.org>
  *   Copyright (C) 2012-2016, 2018 Attila Molnar <attilamolnar@hush.com>
  *   Copyright (C) 2012 Robby <robby@chatbelgie.be>
@@ -128,7 +129,7 @@ void ModuleSpanningTree::ShowLinks(TreeServer* Current, User* user, int hops)
 		{
 			if (user->IsOper())
 			{
-				 ShowLinks(server, user, hops+1);
+				ShowLinks(server, user, hops+1);
 			}
 		}
 		else
@@ -144,7 +145,7 @@ void ModuleSpanningTree::ShowLinks(TreeServer* Current, User* user, int hops)
 		return;
 
 	user->WriteNumeric(RPL_LINKS, Current->GetName(),
-			(((Utils->FlatLinks) && (!user->IsOper())) ? ServerInstance->Config->ServerName : Parent),
+			(((Utils->FlatLinks) && (!user->IsOper())) ? ServerInstance->Config->GetServerName() : Parent),
 			InspIRCd::Format("%d %s", (((Utils->FlatLinks) && (!user->IsOper())) ? 0 : hops), Current->GetDesc().c_str()));
 }
 
@@ -511,6 +512,7 @@ void ModuleSpanningTree::OnUserJoin(Membership* memb, bool sync, bool created_by
 		params.add(memb);
 		params.finalize();
 		params.Broadcast();
+		Utils->SendListLimits(memb->chan, NULL);
 	}
 	else
 	{
@@ -764,8 +766,7 @@ void ModuleSpanningTree::OnUserAway(User* user)
 
 void ModuleSpanningTree::OnUserBack(User* user)
 {
-	if (IS_LOCAL(user))
-		CommandAway::Builder(user).Broadcast();
+	OnUserAway(user);
 }
 
 void ModuleSpanningTree::OnMode(User* source, User* u, Channel* c, const Modes::ChangeList& modes, ModeParser::ModeProcessFlag processflags)
@@ -802,6 +803,14 @@ void ModuleSpanningTree::OnShutdown(const std::string& reason)
 		children.front()->SQuit(reason, true);
 }
 
+void ModuleSpanningTree::OnDecodeMetaData(Extensible* target, const std::string& extname, const std::string& extdata)
+{
+	// HACK: this should use automatically synced user metadata in v4.
+	User* dest = static_cast<User*>(target);
+	if (dest && (extname == "uniqueusername"))
+		dest->uniqueusername = (extdata != "0");
+}
+
 CullResult ModuleSpanningTree::cull()
 {
 	if (Utils)
