@@ -1,9 +1,13 @@
 /*
  * InspIRCd -- Internet Relay Chat Daemon
  *
+ *   Copyright (C) 2018-2020 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2017 B00mX0r <b00mx0r@aureus.pw>
+ *   Copyright (C) 2013-2016 Attila Molnar <attilamolnar@hush.com>
+ *   Copyright (C) 2012, 2019 Robby <robby@chatbelgie.be>
  *   Copyright (C) 2009 Daniel De Graaf <danieldg@inspircd.org>
- *   Copyright (C) 2007-2008 Craig Edwards <craigedwards@brainbox.cc>
  *   Copyright (C) 2008 Robin Burchell <robin+git@viroteck.net>
+ *   Copyright (C) 2007, 2010 Craig Edwards <brain@inspircd.org>
  *   Copyright (C) 2007 Dennis Friis <peavey@inspircd.org>
  *
  * This file is part of InspIRCd.  InspIRCd is free software: you can
@@ -123,7 +127,7 @@ TreeServer::TreeServer(const std::string& Name, const std::string& Desc, const s
 	 * be referenced by its server name. The AddHashEntry()
 	 * call below automatically inserts each TreeServer class
 	 * into the hash_map as it is created. There is a similar
-	 * maintainance call in the destructor to tidy up deleted
+	 * maintenance call in the destructor to tidy up deleted
 	 * servers.
 	 */
 
@@ -251,7 +255,7 @@ void TreeServer::CheckULine()
 	{
 		ConfigTag* tag = i->second;
 		std::string server = tag->getString("server");
-		if (!strcasecmp(server.c_str(), GetName().c_str()))
+		if (irc::equals(server, GetName()))
 		{
 			if (this->IsRoot())
 			{
