@@ -1,7 +1,7 @@
 /*
  * InspIRCd -- Internet Relay Chat Daemon
  *
- *   Copyright (C) 2013-2014, 2017-2019 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2013-2014, 2017-2019, 2021 Sadie Powell <sadie@witchery.services>
  *   Copyright (C) 2013 Adam <Adam@anope.org>
  *   Copyright (C) 2012-2016 Attila Molnar <attilamolnar@hush.com>
  *   Copyright (C) 2012 Robby <robby@chatbelgie.be>
@@ -25,6 +25,7 @@
 
 
 #include "inspircd.h"
+#include "listmode.h"
 
 #include "main.h"
 #include "utils.h"
@@ -274,7 +275,7 @@ void SpanningTreeUtilities::ReadConfiguration()
 		L->Fingerprint = tag->getString("fingerprint");
 		L->HiddenFromStats = tag->getBool("statshidden");
 		L->Timeout = tag->getDuration("timeout", 30);
-		L->Hook = tag->getString("ssl");
+		L->Hook = tag->getString("sslprofile", tag->getString("ssl"));
 		L->Bind = tag->getString("bind");
 		L->Hidden = tag->getBool("hidden");
 
@@ -374,3 +375,24 @@ void SpanningTreeUtilities::SendChannelMessage(User* source, Channel* target, co
 			Sock->WriteLine(msg);
 	}
 }
+
+void SpanningTreeUtilities::SendListLimits(Channel* chan, TreeSocket* sock)
+{
+	std::stringstream buffer;
+	const ModeParser::ListModeList& listmodes = ServerInstance->Modes->GetListModes();
+	for (ModeParser::ListModeList::const_iterator i = listmodes.begin(); i != listmodes.end(); ++i)
+	{
+		ListModeBase* lm = *i;
+		buffer << lm->GetModeChar() << " " << lm->GetLimit(chan) << " ";
+	}
+
+	std::string bufferstr = buffer.str();
+	if (bufferstr.empty())
+		return; // Should never happen.
+
+	bufferstr.erase(bufferstr.end() - 1);
+	if (sock)
+		sock->WriteLine(CommandMetadata::Builder(chan, "maxlist", bufferstr));
+	else
+		CommandMetadata::Builder(chan, "maxlist", bufferstr).Broadcast();
+}
