@@ -1,7 +1,7 @@
 /*
  * InspIRCd -- Internet Relay Chat Daemon
  *
- *   Copyright (C) 2013, 2017-2019 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2013, 2017-2019, 2021 Sadie Powell <sadie@witchery.services>
  *   Copyright (C) 2012-2016 Attila Molnar <attilamolnar@hush.com>
  *   Copyright (C) 2012 Robby <robby@chatbelgie.be>
  *   Copyright (C) 2009 Daniel De Graaf <danieldg@inspircd.org>
@@ -50,7 +50,7 @@ class SpanningTreeUtilities : public classbase
 	CacheRefreshTimer RefreshTimer;
 
  public:
- 	typedef std::set<TreeSocket*> TreeSocketSet;
+	typedef std::set<TreeSocket*> TreeSocketSet;
 	typedef std::map<TreeSocket*, std::pair<std::string, unsigned int> > TimeoutList;
 
 	/** Creator module
@@ -176,6 +176,9 @@ class SpanningTreeUtilities : public classbase
 	/** Sends a PRIVMSG or a NOTICE to a channel obeying an exempt list and an optional prefix
 	 */
 	void SendChannelMessage(User* source, Channel* target, const std::string& text, char status, const ClientProtocol::TagMap& tags, const CUList& exempt_list, const char* message_type, TreeSocket* omit = NULL);
+
+	/** Send the channel list mode limits to either the specified server or all servers if NULL. */
+	void SendListLimits(Channel* chan, TreeSocket* sock = NULL);
 };
 
 inline void SpanningTreeUtilities::DoOneToMany(const CmdBuilder& params)
