@@ -3,7 +3,7 @@
  *
  *   Copyright (C) 2019 nia <nia@netbsd.org>
  *   Copyright (C) 2013-2014, 2016 Attila Molnar <attilamolnar@hush.com>
- *   Copyright (C) 2013, 2016-2017, 2020 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2013, 2016-2017, 2020-2021 Sadie Powell <sadie@witchery.services>
  *   Copyright (C) 2013 Adam <Adam@anope.org>
  *   Copyright (C) 2012 Robby <robby@chatbelgie.be>
  *   Copyright (C) 2012 ChrisTX <xpipe@hotmail.de>
@@ -72,7 +72,7 @@ std::string InspIRCd::GetVersionString(bool getFullVersion)
 {
 	if (getFullVersion)
 		return INSPIRCD_VERSION ". " + Config->ServerName + " :[" + Config->sid + "] " + Config->CustomVersion;
-	return INSPIRCD_BRANCH ". " + Config->ServerName + " :" + Config->CustomVersion;
+	return INSPIRCD_BRANCH ". " + Config->GetServerName() + " :" + Config->CustomVersion;
 }
 
 std::string UIDGenerator::GenerateSID(const std::string& servername, const std::string& serverdesc)
@@ -162,6 +162,13 @@ std::string UIDGenerator::GetUID()
 	return current_uid;
 }
 
+const std::string& Server::GetPublicName() const
+{
+	if (!ServerInstance->Config->HideServer.empty())
+		return ServerInstance->Config->HideServer;
+	return GetName();
+}
+
 void ISupportManager::AppendValue(std::string& buffer, const std::string& value)
 {
 	// If this token has no value then we have nothing to do.
