@@ -1,16 +1,17 @@
 /*
  * InspIRCd -- Internet Relay Chat Daemon
  *
+ *   Copyright (C) 2021 Herman <GermanAizek@yandex.ru>
  *   Copyright (C) 2019 Matt Schatz <genius3000@g3k.solutions>
  *   Copyright (C) 2013, 2017-2020 Sadie Powell <sadie@witchery.services>
  *   Copyright (C) 2013 Adam <Adam@anope.org>
  *   Copyright (C) 2012-2014, 2016 Attila Molnar <attilamolnar@hush.com>
- *   Copyright (C) 2012, 2018-2019 Robby <robby@chatbelgie.be>
+ *   Copyright (C) 2012, 2019 Robby <robby@chatbelgie.be>
  *   Copyright (C) 2009 Uli Schlachter <psychon@inspircd.org>
  *   Copyright (C) 2009 Daniel De Graaf <danieldg@inspircd.org>
  *   Copyright (C) 2007-2009 Robin Burchell <robin+git@viroteck.net>
  *   Copyright (C) 2007 Dennis Friis <peavey@inspircd.org>
- *   Copyright (C) 2006-2008, 2010 Craig Edwards <brain@inspircd.org>
+ *   Copyright (C) 2004, 2006-2008, 2010 Craig Edwards <brain@inspircd.org>
  *
  * This file is part of InspIRCd.  InspIRCd is free software: you can
  * redistribute it and/or modify it under the terms of the GNU General Public
@@ -167,7 +168,7 @@ void XLineManager::CheckELines()
 		LocalUser* u = *u2;
 		u->exempt = false;
 
-		/* This uses safe iteration to ensure that if a line expires here, it doenst trash the iterator */
+		/* This uses safe iteration to ensure that if a line expires here, it doesn't trash the iterator */
 		LookupIter safei;
 
 		for (LookupIter i = ELines.begin(); i != ELines.end(); )
@@ -400,7 +401,7 @@ XLine* XLineManager::MatchesLine(const std::string &type, const std::string &pat
 
 	const time_t current = ServerInstance->Time();
 
-	 LookupIter safei;
+	LookupIter safei;
 
 	for (LookupIter i = x->second.begin(); i != x->second.end(); )
 	{
@@ -493,12 +494,13 @@ void XLineManager::InvokeStats(const std::string& type, unsigned int numeric, St
 			safei = i;
 			safei++;
 
-			if (i->second->duration && current > i->second->expiry)
+			XLine* e = i->second;
+			if (e->duration && current > e->expiry)
 			{
 				ExpireLine(n, i);
 			}
 			else
-				stats.AddRow(numeric, i->second->Displayable(), i->second->set_time, i->second->duration, i->second->source, i->second->reason);
+				stats.AddRow(numeric, e->Displayable(), e->set_time, e->duration, e->source, e->reason);
 			i = safei;
 		}
 	}
@@ -688,6 +690,7 @@ bool QLine::Matches(User *u)
 void QLine::Apply(User* u)
 {
 	/* Force to uuid on apply of Q-line, no need to disconnect anymore :) */
+	u->WriteNumeric(RPL_SAVENICK, u->uuid, "Your nickname has been Q-lined.");
 	u->ChangeNick(u->uuid);
 }
 
