@@ -3,7 +3,7 @@
  *
  *   Copyright (C) 2020 Matt Schatz <genius3000@g3k.solutions>
  *   Copyright (C) 2013-2015 Attila Molnar <attilamolnar@hush.com>
- *   Copyright (C) 2013, 2015, 2018-2019 Sadie Powell <sadie@witchery.services>
+ *   Copyright (C) 2013, 2015, 2018-2019, 2021 Sadie Powell <sadie@witchery.services>
  *   Copyright (C) 2012-2013 ChrisTX <xpipe@hotmail.de>
  *   Copyright (C) 2012 Robby <robby@chatbelgie.be>
  *   Copyright (C) 2011, 2014, 2019 Adam <Adam@anope.org>
@@ -11,7 +11,7 @@
  *   Copyright (C) 2007-2009 Robin Burchell <robin+git@viroteck.net>
  *   Copyright (C) 2007-2008 Craig Edwards <brain@inspircd.org>
  *   Copyright (C) 2007, 2009 Dennis Friis <peavey@inspircd.org>
- *   Copyright (C) 2007 burlex <burlex@e03df62e-2008-0410-955e-edbf42e46eb7>
+ *   Copyright (C) 2007 burlex
  *
  * This file is part of InspIRCd.  InspIRCd is free software: you can
  * redistribute it and/or modify it under the terms of the GNU General Public
@@ -61,6 +61,11 @@
 #define DllExport __declspec(dllimport)
 #endif
 
+// File numbers for standard streams.
+#define STDIN_FILENO 0
+#define STDOUT_FILENO 1
+#define STDERR_FILENO 2
+
 /* Redirect main() through a different method in win32service.cpp, to intercept service startup */
 #define ENTRYPOINT CoreExport int smain(int argc, char** argv)
 
@@ -102,6 +107,8 @@ typedef SSIZE_T ssize_t;
 #define popen _popen
 #define pclose _pclose
 #define getpid _getpid
+#define dup _dup
+#define fdopen _fdopen
 
 // warning: 'identifier' : class 'type' needs to have dll-interface to be used by clients of class 'type2'
 // Normally, this is a huge problem, but due to our new/delete remap, we can ignore it.
@@ -189,3 +196,11 @@ struct sockaddr_un
 	ADDRESS_FAMILY sun_family;
 	char sun_path[6];
 };
+
+struct WindowsStream
+{
+	WORD BackgroundColor;
+	WORD ForegroundColor;
+	HANDLE Handle;
+	WindowsStream(DWORD handle);
+};
